// ============================================================================
// Rocks'n'Diamonds - McDuffin Strikes Back!
// ----------------------------------------------------------------------------
// (c) 1995-2014 by Artsoft Entertainment
//                  Holger Schemel
//                  info@artsoft.org
//                  https://www.artsoft.org/
// ----------------------------------------------------------------------------
// conf_gfx.h
// ============================================================================

// ------- this file was automatically generated -- do not edit by hand -------

#ifndef CONF_GFX_H
#define CONF_GFX_H

// values for graphics configuration (normal elements)

#define IMG_BD_WALL					0
#define IMG_BD_WALL_EDITOR				1
#define IMG_BD_ROCK					2
#define IMG_BD_ROCK_EDITOR				3
#define IMG_BD_ROCK_MOVING_LEFT				4
#define IMG_BD_ROCK_MOVING_RIGHT			5
#define IMG_BD_ROCK_PUSHING_LEFT			6
#define IMG_BD_ROCK_PUSHING_RIGHT			7
#define IMG_BD_DIAMOND					8
#define IMG_BD_DIAMOND_MOVING				9
#define IMG_BD_DIAMOND_FALLING				10
#define IMG_BD_DIAMOND_COLLECTING			11
#define IMG_BD_MAGIC_WALL				12
#define IMG_BD_MAGIC_WALL_ACTIVE			13
#define IMG_BD_MAGIC_WALL_FILLING			14
#define IMG_BD_MAGIC_WALL_FULL				15
#define IMG_BD_MAGIC_WALL_EMPTYING			16
#define IMG_BD_MAGIC_WALL_DEAD				17
#define IMG_BD_AMOEBA					18
#define IMG_BD_AMOEBA_EDITOR				19
#define IMG_BD_BUTTERFLY				20
#define IMG_BD_BUTTERFLY_RIGHT				21
#define IMG_BD_BUTTERFLY_RIGHT_EDITOR			22
#define IMG_BD_BUTTERFLY_UP				23
#define IMG_BD_BUTTERFLY_UP_EDITOR			24
#define IMG_BD_BUTTERFLY_LEFT				25
#define IMG_BD_BUTTERFLY_LEFT_EDITOR			26
#define IMG_BD_BUTTERFLY_DOWN				27
#define IMG_BD_BUTTERFLY_DOWN_EDITOR			28
#define IMG_BD_FIREFLY					29
#define IMG_BD_FIREFLY_RIGHT				30
#define IMG_BD_FIREFLY_RIGHT_EDITOR			31
#define IMG_BD_FIREFLY_UP				32
#define IMG_BD_FIREFLY_UP_EDITOR			33
#define IMG_BD_FIREFLY_LEFT				34
#define IMG_BD_FIREFLY_LEFT_EDITOR			35
#define IMG_BD_FIREFLY_DOWN				36
#define IMG_BD_FIREFLY_DOWN_EDITOR			37
#define IMG_SP_DEFAULT_EXPLODING			38
#define IMG_SP_ZONK					39
#define IMG_SP_ZONK_MOVING_LEFT				40
#define IMG_SP_ZONK_MOVING_RIGHT			41
#define IMG_SP_ZONK_PUSHING_LEFT			42
#define IMG_SP_ZONK_PUSHING_RIGHT			43
#define IMG_SP_BASE					44
#define IMG_SP_BASE_DIGGING				45
#define IMG_SP_BASE_SNAPPING				46
#define IMG_SP_MURPHY					47
#define IMG_SP_MURPHY_MOVING_LEFT			48
#define IMG_SP_MURPHY_MOVING_RIGHT			49
#define IMG_SP_MURPHY_DIGGING_LEFT			50
#define IMG_SP_MURPHY_DIGGING_RIGHT			51
#define IMG_SP_MURPHY_COLLECTING_LEFT			52
#define IMG_SP_MURPHY_COLLECTING_RIGHT			53
#define IMG_SP_MURPHY_PUSHING_LEFT			54
#define IMG_SP_MURPHY_PUSHING_RIGHT			55
#define IMG_SP_MURPHY_SNAPPING_LEFT			56
#define IMG_SP_MURPHY_SNAPPING_RIGHT			57
#define IMG_SP_MURPHY_SNAPPING_UP			58
#define IMG_SP_MURPHY_SNAPPING_DOWN			59
#define IMG_SP_MURPHY_BORING				60
#define IMG_SP_MURPHY_BORING_1				61
#define IMG_SP_MURPHY_SLEEPING_LEFT			62
#define IMG_SP_MURPHY_SLEEPING_RIGHT			63
#define IMG_SP_MURPHY_DROPPING				64
#define IMG_SP_MURPHY_SHRINKING				65
#define IMG_SP_MURPHY_CLONE				66
#define IMG_SP_INFOTRON					67
#define IMG_SP_INFOTRON_EDITOR				68
#define IMG_SP_INFOTRON_MOVING_LEFT			69
#define IMG_SP_INFOTRON_MOVING_RIGHT			70
#define IMG_SP_INFOTRON_COLLECTING			71
#define IMG_SP_CHIP_SINGLE				72
#define IMG_SP_CHIP_LEFT				73
#define IMG_SP_CHIP_RIGHT				74
#define IMG_SP_CHIP_TOP					75
#define IMG_SP_CHIP_BOTTOM				76
#define IMG_SP_HARDWARE_GRAY				77
#define IMG_SP_HARDWARE_GREEN				78
#define IMG_SP_HARDWARE_BLUE				79
#define IMG_SP_HARDWARE_RED				80
#define IMG_SP_HARDWARE_YELLOW				81
#define IMG_SP_EXIT_CLOSED				82
#define IMG_SP_EXIT_OPENING				83
#define IMG_SP_EXIT_OPEN				84
#define IMG_SP_EXIT_CLOSING				85
#define IMG_SP_DISK_ORANGE				86
#define IMG_SP_DISK_YELLOW				87
#define IMG_SP_DISK_RED					88
#define IMG_SP_DISK_RED_COLLECTING			89
#define IMG_SP_DISK_RED_ACTIVE				90
#define IMG_SP_PORT_RIGHT				91
#define IMG_SP_PORT_DOWN				92
#define IMG_SP_PORT_LEFT				93
#define IMG_SP_PORT_UP					94
#define IMG_SP_PORT_HORIZONTAL				95
#define IMG_SP_PORT_VERTICAL				96
#define IMG_SP_PORT_ANY					97
#define IMG_SP_GRAVITY_PORT_RIGHT			98
#define IMG_SP_GRAVITY_PORT_RIGHT_EDITOR		99
#define IMG_SP_GRAVITY_PORT_DOWN			100
#define IMG_SP_GRAVITY_PORT_DOWN_EDITOR			101
#define IMG_SP_GRAVITY_PORT_LEFT			102
#define IMG_SP_GRAVITY_PORT_LEFT_EDITOR			103
#define IMG_SP_GRAVITY_PORT_UP				104
#define IMG_SP_GRAVITY_PORT_UP_EDITOR			105
#define IMG_SP_GRAVITY_ON_PORT_RIGHT			106
#define IMG_SP_GRAVITY_ON_PORT_RIGHT_EDITOR		107
#define IMG_SP_GRAVITY_ON_PORT_DOWN			108
#define IMG_SP_GRAVITY_ON_PORT_DOWN_EDITOR		109
#define IMG_SP_GRAVITY_ON_PORT_LEFT			110
#define IMG_SP_GRAVITY_ON_PORT_LEFT_EDITOR		111
#define IMG_SP_GRAVITY_ON_PORT_UP			112
#define IMG_SP_GRAVITY_ON_PORT_UP_EDITOR		113
#define IMG_SP_GRAVITY_OFF_PORT_RIGHT			114
#define IMG_SP_GRAVITY_OFF_PORT_RIGHT_EDITOR		115
#define IMG_SP_GRAVITY_OFF_PORT_DOWN			116
#define IMG_SP_GRAVITY_OFF_PORT_DOWN_EDITOR		117
#define IMG_SP_GRAVITY_OFF_PORT_LEFT			118
#define IMG_SP_GRAVITY_OFF_PORT_LEFT_EDITOR		119
#define IMG_SP_GRAVITY_OFF_PORT_UP			120
#define IMG_SP_GRAVITY_OFF_PORT_UP_EDITOR		121
#define IMG_SP_SNIKSNAK					122
#define IMG_SP_SNIKSNAK_LEFT				123
#define IMG_SP_SNIKSNAK_RIGHT				124
#define IMG_SP_SNIKSNAK_UP				125
#define IMG_SP_SNIKSNAK_DOWN				126
#define IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_UP		127
#define IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_DOWN		128
#define IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_UP		129
#define IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_DOWN		130
#define IMG_SP_SNIKSNAK_TURNING_FROM_UP_LEFT		131
#define IMG_SP_SNIKSNAK_TURNING_FROM_UP_RIGHT		132
#define IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_LEFT		133
#define IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_RIGHT		134
#define IMG_SP_ELECTRON					135
#define IMG_SP_ELECTRON_EDITOR				136
#define IMG_SP_ELECTRON_EXPLODING			137
#define IMG_SP_TERMINAL					138
#define IMG_SP_TERMINAL_EDITOR				139
#define IMG_SP_TERMINAL_ACTIVE				140
#define IMG_SP_BUGGY_BASE				141
#define IMG_SP_BUGGY_BASE_EDITOR			142
#define IMG_SP_BUGGY_BASE_ACTIVATING			143
#define IMG_SP_BUGGY_BASE_ACTIVE			144
#define IMG_SP_HARDWARE_BASE_1				145
#define IMG_SP_HARDWARE_BASE_2				146
#define IMG_SP_HARDWARE_BASE_3				147
#define IMG_SP_HARDWARE_BASE_4				148
#define IMG_SP_HARDWARE_BASE_5				149
#define IMG_SP_HARDWARE_BASE_6				150
#define IMG_SOKOBAN_OBJECT				151
#define IMG_SOKOBAN_FIELD_EMPTY				152
#define IMG_SOKOBAN_FIELD_FULL				153
#define IMG_SOKOBAN_FIELD_PLAYER			154
#define IMG_EMPTY_SPACE					155
#define IMG_SAND					156
#define IMG_SAND_CRUMBLED				157
#define IMG_SAND_DIGGING_LEFT				158
#define IMG_SAND_DIGGING_RIGHT				159
#define IMG_SAND_DIGGING_UP				160
#define IMG_SAND_DIGGING_DOWN				161
#define IMG_SAND_DIGGING_LEFT_CRUMBLED			162
#define IMG_SAND_DIGGING_RIGHT_CRUMBLED			163
#define IMG_SAND_DIGGING_UP_CRUMBLED			164
#define IMG_SAND_DIGGING_DOWN_CRUMBLED			165
#define IMG_WALL					166
#define IMG_WALL_SLIPPERY				167
#define IMG_STEELWALL					168
#define IMG_ROCK					169
#define IMG_ROCK_MOVING_LEFT				170
#define IMG_ROCK_MOVING_RIGHT				171
#define IMG_ROCK_PUSHING_LEFT				172
#define IMG_ROCK_PUSHING_RIGHT				173
#define IMG_EMERALD					174
#define IMG_EMERALD_MOVING				175
#define IMG_EMERALD_FALLING				176
#define IMG_EMERALD_COLLECTING				177
#define IMG_DIAMOND					178
#define IMG_DIAMOND_MOVING				179
#define IMG_DIAMOND_FALLING				180
#define IMG_DIAMOND_COLLECTING				181
#define IMG_BOMB					182
#define IMG_NUT						183
#define IMG_NUT_BREAKING				184
#define IMG_DYNAMITE					185
#define IMG_DYNAMITE_ACTIVE				186
#define IMG_DYNAMITE_COLLECTING				187
#define IMG_EM_DYNAMITE					188
#define IMG_EM_DYNAMITE_ACTIVE				189
#define IMG_EM_DYNAMITE_ACTIVE_EDITOR			190
#define IMG_EM_DYNAMITE_COLLECTING			191
#define IMG_WALL_EMERALD				192
#define IMG_WALL_DIAMOND				193
#define IMG_BUG						194
#define IMG_BUG_RIGHT					195
#define IMG_BUG_UP					196
#define IMG_BUG_LEFT					197
#define IMG_BUG_DOWN					198
#define IMG_BUG_MOVING_RIGHT				199
#define IMG_BUG_MOVING_UP				200
#define IMG_BUG_MOVING_LEFT				201
#define IMG_BUG_MOVING_DOWN				202
#define IMG_BUG_TURNING_FROM_RIGHT_UP			203
#define IMG_BUG_TURNING_FROM_UP_LEFT			204
#define IMG_BUG_TURNING_FROM_LEFT_DOWN			205
#define IMG_BUG_TURNING_FROM_DOWN_RIGHT			206
#define IMG_BUG_TURNING_FROM_RIGHT_DOWN			207
#define IMG_BUG_TURNING_FROM_UP_RIGHT			208
#define IMG_BUG_TURNING_FROM_LEFT_UP			209
#define IMG_BUG_TURNING_FROM_DOWN_LEFT			210
#define IMG_SPACESHIP					211
#define IMG_SPACESHIP_RIGHT				212
#define IMG_SPACESHIP_UP				213
#define IMG_SPACESHIP_LEFT				214
#define IMG_SPACESHIP_DOWN				215
#define IMG_SPACESHIP_MOVING_RIGHT			216
#define IMG_SPACESHIP_MOVING_UP				217
#define IMG_SPACESHIP_MOVING_LEFT			218
#define IMG_SPACESHIP_MOVING_DOWN			219
#define IMG_SPACESHIP_TURNING_FROM_RIGHT_UP		220
#define IMG_SPACESHIP_TURNING_FROM_UP_LEFT		221
#define IMG_SPACESHIP_TURNING_FROM_LEFT_DOWN		222
#define IMG_SPACESHIP_TURNING_FROM_DOWN_RIGHT		223
#define IMG_SPACESHIP_TURNING_FROM_RIGHT_DOWN		224
#define IMG_SPACESHIP_TURNING_FROM_UP_RIGHT		225
#define IMG_SPACESHIP_TURNING_FROM_LEFT_UP		226
#define IMG_SPACESHIP_TURNING_FROM_DOWN_LEFT		227
#define IMG_YAMYAM					228
#define IMG_YAMYAM_LEFT					229
#define IMG_YAMYAM_LEFT_EDITOR				230
#define IMG_YAMYAM_RIGHT				231
#define IMG_YAMYAM_RIGHT_EDITOR				232
#define IMG_YAMYAM_UP					233
#define IMG_YAMYAM_UP_EDITOR				234
#define IMG_YAMYAM_DOWN					235
#define IMG_YAMYAM_DOWN_EDITOR				236
#define IMG_YAMYAM_MOVING				237
#define IMG_ROBOT					238
#define IMG_ROBOT_MOVING				239
#define IMG_ROBOT_WHEEL					240
#define IMG_ROBOT_WHEEL_ACTIVE				241
#define IMG_MAGIC_WALL					242
#define IMG_MAGIC_WALL_ACTIVE				243
#define IMG_MAGIC_WALL_FILLING				244
#define IMG_MAGIC_WALL_FULL				245
#define IMG_MAGIC_WALL_EMPTYING				246
#define IMG_MAGIC_WALL_DEAD				247
#define IMG_DC_MAGIC_WALL				248
#define IMG_DC_MAGIC_WALL_ACTIVE			249
#define IMG_DC_MAGIC_WALL_FILLING			250
#define IMG_DC_MAGIC_WALL_FULL				251
#define IMG_DC_MAGIC_WALL_EMPTYING			252
#define IMG_DC_MAGIC_WALL_DEAD				253
#define IMG_QUICKSAND_EMPTY				254
#define IMG_QUICKSAND_FILLING				255
#define IMG_QUICKSAND_FULL				256
#define IMG_QUICKSAND_FULL_EDITOR			257
#define IMG_QUICKSAND_EMPTYING				258
#define IMG_QUICKSAND_FAST_EMPTY			259
#define IMG_QUICKSAND_FAST_FILLING			260
#define IMG_QUICKSAND_FAST_FULL				261
#define IMG_QUICKSAND_FAST_FULL_EDITOR			262
#define IMG_QUICKSAND_FAST_EMPTYING			263
#define IMG_ACID_POOL_TOPLEFT				264
#define IMG_ACID_POOL_TOPRIGHT				265
#define IMG_ACID_POOL_BOTTOMLEFT			266
#define IMG_ACID_POOL_BOTTOM				267
#define IMG_ACID_POOL_BOTTOMRIGHT			268
#define IMG_ACID					269
#define IMG_ACID_SPLASH_LEFT				270
#define IMG_ACID_SPLASH_RIGHT				271
#define IMG_AMOEBA_DROP					272
#define IMG_AMOEBA_GROWING				273
#define IMG_AMOEBA_SHRINKING				274
#define IMG_AMOEBA_WET					275
#define IMG_AMOEBA_WET_EDITOR				276
#define IMG_AMOEBA_DROPPING				277
#define IMG_AMOEBA_DRY					278
#define IMG_AMOEBA_FULL					279
#define IMG_AMOEBA_FULL_EDITOR				280
#define IMG_AMOEBA_DEAD					281
#define IMG_AMOEBA_DEAD_EDITOR				282
#define IMG_EM_KEY_1					283
#define IMG_EM_KEY_1_COLLECTING				284
#define IMG_EM_KEY_2					285
#define IMG_EM_KEY_2_COLLECTING				286
#define IMG_EM_KEY_3					287
#define IMG_EM_KEY_3_COLLECTING				288
#define IMG_EM_KEY_4					289
#define IMG_EM_KEY_4_COLLECTING				290
#define IMG_DC_KEY_WHITE				291
#define IMG_DC_KEY_WHITE_COLLECTING			292
#define IMG_EM_GATE_1					293
#define IMG_EM_GATE_2					294
#define IMG_EM_GATE_3					295
#define IMG_EM_GATE_4					296
#define IMG_DC_GATE_WHITE				297
#define IMG_EM_GATE_1_GRAY				298
#define IMG_EM_GATE_1_GRAY_EDITOR			299
#define IMG_EM_GATE_1_GRAY_ACTIVE			300
#define IMG_EM_GATE_2_GRAY				301
#define IMG_EM_GATE_2_GRAY_EDITOR			302
#define IMG_EM_GATE_2_GRAY_ACTIVE			303
#define IMG_EM_GATE_3_GRAY				304
#define IMG_EM_GATE_3_GRAY_EDITOR			305
#define IMG_EM_GATE_3_GRAY_ACTIVE			306
#define IMG_EM_GATE_4_GRAY				307
#define IMG_EM_GATE_4_GRAY_EDITOR			308
#define IMG_EM_GATE_4_GRAY_ACTIVE			309
#define IMG_DC_GATE_WHITE_GRAY				310
#define IMG_DC_GATE_WHITE_GRAY_EDITOR			311
#define IMG_DC_GATE_WHITE_GRAY_ACTIVE			312
#define IMG_DC_GATE_FAKE_GRAY				313
#define IMG_EXIT_CLOSED					314
#define IMG_EXIT_OPENING				315
#define IMG_EXIT_OPEN					316
#define IMG_EXIT_CLOSING				317
#define IMG_STEEL_EXIT_CLOSED				318
#define IMG_STEEL_EXIT_OPENING				319
#define IMG_STEEL_EXIT_OPEN				320
#define IMG_STEEL_EXIT_CLOSING				321
#define IMG_EM_EXIT_CLOSED				322
#define IMG_EM_EXIT_OPENING				323
#define IMG_EM_EXIT_OPEN				324
#define IMG_EM_EXIT_CLOSING				325
#define IMG_EM_STEEL_EXIT_CLOSED			326
#define IMG_EM_STEEL_EXIT_OPENING			327
#define IMG_EM_STEEL_EXIT_OPEN				328
#define IMG_EM_STEEL_EXIT_CLOSING			329
#define IMG_BALLOON					330
#define IMG_BALLOON_MOVING				331
#define IMG_BALLOON_PUSHING				332
#define IMG_BALLOON_SWITCH_LEFT				333
#define IMG_BALLOON_SWITCH_RIGHT			334
#define IMG_BALLOON_SWITCH_UP				335
#define IMG_BALLOON_SWITCH_DOWN				336
#define IMG_BALLOON_SWITCH_ANY				337
#define IMG_BALLOON_SWITCH_NONE				338
#define IMG_SPRING					339
#define IMG_SPRING_LEFT					340
#define IMG_SPRING_RIGHT				341
#define IMG_EMC_STEELWALL_1				342
#define IMG_EMC_STEELWALL_2				343
#define IMG_EMC_STEELWALL_3				344
#define IMG_EMC_STEELWALL_4				345
#define IMG_EMC_WALL_1					346
#define IMG_EMC_WALL_2					347
#define IMG_EMC_WALL_3					348
#define IMG_EMC_WALL_4					349
#define IMG_EMC_WALL_5					350
#define IMG_EMC_WALL_6					351
#define IMG_EMC_WALL_7					352
#define IMG_EMC_WALL_8					353
#define IMG_INVISIBLE_STEELWALL				354
#define IMG_INVISIBLE_STEELWALL_EDITOR			355
#define IMG_INVISIBLE_STEELWALL_ACTIVE			356
#define IMG_INVISIBLE_WALL				357
#define IMG_INVISIBLE_WALL_EDITOR			358
#define IMG_INVISIBLE_WALL_ACTIVE			359
#define IMG_INVISIBLE_SAND				360
#define IMG_INVISIBLE_SAND_EDITOR			361
#define IMG_INVISIBLE_SAND_ACTIVE			362
#define IMG_INVISIBLE_SAND_ACTIVE_CRUMBLED		363
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT		364
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT		365
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP		366
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN		367
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT_CRUMBLED	368
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT_CRUMBLED	369
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP_CRUMBLED	370
#define IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN_CRUMBLED	371
#define IMG_CONVEYOR_BELT_1_MIDDLE			372
#define IMG_CONVEYOR_BELT_1_MIDDLE_ACTIVE		373
#define IMG_CONVEYOR_BELT_1_LEFT			374
#define IMG_CONVEYOR_BELT_1_LEFT_ACTIVE			375
#define IMG_CONVEYOR_BELT_1_RIGHT			376
#define IMG_CONVEYOR_BELT_1_RIGHT_ACTIVE		377
#define IMG_CONVEYOR_BELT_1_SWITCH_LEFT			378
#define IMG_CONVEYOR_BELT_1_SWITCH_MIDDLE		379
#define IMG_CONVEYOR_BELT_1_SWITCH_RIGHT		380
#define IMG_CONVEYOR_BELT_2_MIDDLE			381
#define IMG_CONVEYOR_BELT_2_MIDDLE_ACTIVE		382
#define IMG_CONVEYOR_BELT_2_LEFT			383
#define IMG_CONVEYOR_BELT_2_LEFT_ACTIVE			384
#define IMG_CONVEYOR_BELT_2_RIGHT			385
#define IMG_CONVEYOR_BELT_2_RIGHT_ACTIVE		386
#define IMG_CONVEYOR_BELT_2_SWITCH_LEFT			387
#define IMG_CONVEYOR_BELT_2_SWITCH_MIDDLE		388
#define IMG_CONVEYOR_BELT_2_SWITCH_RIGHT		389
#define IMG_CONVEYOR_BELT_3_MIDDLE			390
#define IMG_CONVEYOR_BELT_3_MIDDLE_ACTIVE		391
#define IMG_CONVEYOR_BELT_3_LEFT			392
#define IMG_CONVEYOR_BELT_3_LEFT_ACTIVE			393
#define IMG_CONVEYOR_BELT_3_RIGHT			394
#define IMG_CONVEYOR_BELT_3_RIGHT_ACTIVE		395
#define IMG_CONVEYOR_BELT_3_SWITCH_LEFT			396
#define IMG_CONVEYOR_BELT_3_SWITCH_MIDDLE		397
#define IMG_CONVEYOR_BELT_3_SWITCH_RIGHT		398
#define IMG_CONVEYOR_BELT_4_MIDDLE			399
#define IMG_CONVEYOR_BELT_4_MIDDLE_ACTIVE		400
#define IMG_CONVEYOR_BELT_4_LEFT			401
#define IMG_CONVEYOR_BELT_4_LEFT_ACTIVE			402
#define IMG_CONVEYOR_BELT_4_RIGHT			403
#define IMG_CONVEYOR_BELT_4_RIGHT_ACTIVE		404
#define IMG_CONVEYOR_BELT_4_SWITCH_LEFT			405
#define IMG_CONVEYOR_BELT_4_SWITCH_MIDDLE		406
#define IMG_CONVEYOR_BELT_4_SWITCH_RIGHT		407
#define IMG_SWITCHGATE_SWITCH_UP			408
#define IMG_SWITCHGATE_SWITCH_DOWN			409
#define IMG_DC_SWITCHGATE_SWITCH_UP			410
#define IMG_DC_SWITCHGATE_SWITCH_DOWN			411
#define IMG_LIGHT_SWITCH				412
#define IMG_LIGHT_SWITCH_ACTIVE				413
#define IMG_TIMEGATE_SWITCH				414
#define IMG_TIMEGATE_SWITCH_ACTIVE			415
#define IMG_DC_TIMEGATE_SWITCH				416
#define IMG_DC_TIMEGATE_SWITCH_ACTIVE			417
#define IMG_ENVELOPE_1					418
#define IMG_ENVELOPE_1_COLLECTING			419
#define IMG_ENVELOPE_2					420
#define IMG_ENVELOPE_2_COLLECTING			421
#define IMG_ENVELOPE_3					422
#define IMG_ENVELOPE_3_COLLECTING			423
#define IMG_ENVELOPE_4					424
#define IMG_ENVELOPE_4_COLLECTING			425
#define IMG_SIGN_RADIOACTIVITY				426
#define IMG_SIGN_GIVE_WAY				427
#define IMG_SIGN_NO_ENTRY				428
#define IMG_SIGN_EMERGENCY_EXIT				429
#define IMG_SIGN_YIN_YANG				430
#define IMG_SIGN_EXCLAMATION				431
#define IMG_SIGN_STOP					432
#define IMG_SIGN_PARKING				433
#define IMG_SIGN_WHEELCHAIR				434
#define IMG_SIGN_ENTRY_FORBIDDEN			435
#define IMG_SPERMS					436
#define IMG_BULLET					437
#define IMG_HEART					438
#define IMG_CROSS					439
#define IMG_FRANKIE					440
#define IMG_SIGN_SPERMS					441
#define IMG_SIGN_BULLET					442
#define IMG_SIGN_HEART					443
#define IMG_SIGN_CROSS					444
#define IMG_SIGN_FRANKIE				445
#define IMG_LANDMINE					446
#define IMG_DC_LANDMINE					447
#define IMG_STEELWALL_SLIPPERY				448
#define IMG_EXTRA_TIME					449
#define IMG_EXTRA_TIME_COLLECTING			450
#define IMG_SHIELD_NORMAL				451
#define IMG_SHIELD_NORMAL_ACTIVE			452
#define IMG_SHIELD_NORMAL_COLLECTING			453
#define IMG_SHIELD_DEADLY				454
#define IMG_SHIELD_DEADLY_ACTIVE			455
#define IMG_SHIELD_DEADLY_COLLECTING			456
#define IMG_SWITCHGATE_CLOSED				457
#define IMG_SWITCHGATE_OPENING				458
#define IMG_SWITCHGATE_OPEN				459
#define IMG_SWITCHGATE_CLOSING				460
#define IMG_TIMEGATE_CLOSED				461
#define IMG_TIMEGATE_OPENING				462
#define IMG_TIMEGATE_OPEN				463
#define IMG_TIMEGATE_CLOSING				464
#define IMG_PEARL					465
#define IMG_PEARL_BREAKING				466
#define IMG_PEARL_COLLECTING				467
#define IMG_CRYSTAL					468
#define IMG_CRYSTAL_COLLECTING				469
#define IMG_WALL_PEARL					470
#define IMG_WALL_CRYSTAL				471
#define IMG_DC_STEELWALL_1_LEFT				472
#define IMG_DC_STEELWALL_1_RIGHT			473
#define IMG_DC_STEELWALL_1_TOP				474
#define IMG_DC_STEELWALL_1_BOTTOM			475
#define IMG_DC_STEELWALL_1_HORIZONTAL			476
#define IMG_DC_STEELWALL_1_VERTICAL			477
#define IMG_DC_STEELWALL_1_TOPLEFT			478
#define IMG_DC_STEELWALL_1_TOPRIGHT			479
#define IMG_DC_STEELWALL_1_BOTTOMLEFT			480
#define IMG_DC_STEELWALL_1_BOTTOMRIGHT			481
#define IMG_DC_STEELWALL_1_TOPLEFT_2			482
#define IMG_DC_STEELWALL_1_TOPRIGHT_2			483
#define IMG_DC_STEELWALL_1_BOTTOMLEFT_2			484
#define IMG_DC_STEELWALL_1_BOTTOMRIGHT_2		485
#define IMG_DC_STEELWALL_2_LEFT				486
#define IMG_DC_STEELWALL_2_RIGHT			487
#define IMG_DC_STEELWALL_2_TOP				488
#define IMG_DC_STEELWALL_2_BOTTOM			489
#define IMG_DC_STEELWALL_2_HORIZONTAL			490
#define IMG_DC_STEELWALL_2_VERTICAL			491
#define IMG_DC_STEELWALL_2_MIDDLE			492
#define IMG_DC_STEELWALL_2_SINGLE			493
#define IMG_TUBE_RIGHT_DOWN				494
#define IMG_TUBE_HORIZONTAL_DOWN			495
#define IMG_TUBE_LEFT_DOWN				496
#define IMG_TUBE_HORIZONTAL				497
#define IMG_TUBE_VERTICAL_RIGHT				498
#define IMG_TUBE_ANY					499
#define IMG_TUBE_VERTICAL_LEFT				500
#define IMG_TUBE_VERTICAL				501
#define IMG_TUBE_RIGHT_UP				502
#define IMG_TUBE_HORIZONTAL_UP				503
#define IMG_TUBE_LEFT_UP				504
#define IMG_TRAP					505
#define IMG_TRAP_ACTIVE					506
#define IMG_DX_SUPABOMB					507
#define IMG_KEY_1					508
#define IMG_KEY_1_COLLECTING				509
#define IMG_KEY_2					510
#define IMG_KEY_2_COLLECTING				511
#define IMG_KEY_3					512
#define IMG_KEY_3_COLLECTING				513
#define IMG_KEY_4					514
#define IMG_KEY_4_COLLECTING				515
#define IMG_GATE_1					516
#define IMG_GATE_2					517
#define IMG_GATE_3					518
#define IMG_GATE_4					519
#define IMG_GATE_1_GRAY					520
#define IMG_GATE_1_GRAY_EDITOR				521
#define IMG_GATE_1_GRAY_ACTIVE				522
#define IMG_GATE_2_GRAY					523
#define IMG_GATE_2_GRAY_EDITOR				524
#define IMG_GATE_2_GRAY_ACTIVE				525
#define IMG_GATE_3_GRAY					526
#define IMG_GATE_3_GRAY_EDITOR				527
#define IMG_GATE_3_GRAY_ACTIVE				528
#define IMG_GATE_4_GRAY					529
#define IMG_GATE_4_GRAY_EDITOR				530
#define IMG_GATE_4_GRAY_ACTIVE				531
#define IMG_GAME_OF_LIFE				532
#define IMG_BIOMAZE					533
#define IMG_PACMAN					534
#define IMG_PACMAN_RIGHT				535
#define IMG_PACMAN_UP					536
#define IMG_PACMAN_LEFT					537
#define IMG_PACMAN_DOWN					538
#define IMG_PACMAN_TURNING_FROM_RIGHT			539
#define IMG_PACMAN_TURNING_FROM_UP			540
#define IMG_PACMAN_TURNING_FROM_LEFT			541
#define IMG_PACMAN_TURNING_FROM_DOWN			542
#define IMG_LAMP					543
#define IMG_LAMP_ACTIVE					544
#define IMG_TIME_ORB_FULL				545
#define IMG_TIME_ORB_EMPTY				546
#define IMG_EMERALD_YELLOW				547
#define IMG_EMERALD_YELLOW_MOVING			548
#define IMG_EMERALD_YELLOW_FALLING			549
#define IMG_EMERALD_YELLOW_COLLECTING			550
#define IMG_EMERALD_RED					551
#define IMG_EMERALD_RED_MOVING				552
#define IMG_EMERALD_RED_FALLING				553
#define IMG_EMERALD_RED_COLLECTING			554
#define IMG_EMERALD_PURPLE				555
#define IMG_EMERALD_PURPLE_MOVING			556
#define IMG_EMERALD_PURPLE_FALLING			557
#define IMG_EMERALD_PURPLE_COLLECTING			558
#define IMG_WALL_EMERALD_YELLOW				559
#define IMG_WALL_EMERALD_RED				560
#define IMG_WALL_EMERALD_PURPLE				561
#define IMG_WALL_BD_DIAMOND				562
#define IMG_EXPANDABLE_WALL				563
#define IMG_EXPANDABLE_WALL_HORIZONTAL			564
#define IMG_EXPANDABLE_WALL_HORIZONTAL_EDITOR		565
#define IMG_EXPANDABLE_WALL_VERTICAL			566
#define IMG_EXPANDABLE_WALL_VERTICAL_EDITOR		567
#define IMG_EXPANDABLE_WALL_ANY				568
#define IMG_EXPANDABLE_WALL_ANY_EDITOR			569
#define IMG_EXPANDABLE_STEELWALL_HORIZONTAL		570
#define IMG_EXPANDABLE_STEELWALL_HORIZONTAL_EDITOR	571
#define IMG_EXPANDABLE_STEELWALL_VERTICAL		572
#define IMG_EXPANDABLE_STEELWALL_VERTICAL_EDITOR	573
#define IMG_EXPANDABLE_STEELWALL_ANY			574
#define IMG_EXPANDABLE_STEELWALL_ANY_EDITOR		575
#define IMG_BD_EXPANDABLE_WALL				576
#define IMG_BD_EXPANDABLE_WALL_EDITOR			577
#define IMG_EXPANDABLE_WALL_GROWING_LEFT		578
#define IMG_EXPANDABLE_WALL_GROWING_RIGHT		579
#define IMG_EXPANDABLE_WALL_GROWING_UP			580
#define IMG_EXPANDABLE_WALL_GROWING_DOWN		581
#define IMG_EXPANDABLE_STEELWALL_GROWING_LEFT		582
#define IMG_EXPANDABLE_STEELWALL_GROWING_RIGHT		583
#define IMG_EXPANDABLE_STEELWALL_GROWING_UP		584
#define IMG_EXPANDABLE_STEELWALL_GROWING_DOWN		585
#define IMG_BLACK_ORB					586
#define IMG_SPEED_PILL					587
#define IMG_SPEED_PILL_COLLECTING			588
#define IMG_DARK_YAMYAM					589
#define IMG_DYNABOMB					590
#define IMG_DYNABOMB_ACTIVE				591
#define IMG_DYNABOMB_PLAYER_1				592
#define IMG_DYNABOMB_PLAYER_1_ACTIVE			593
#define IMG_DYNABOMB_PLAYER_2				594
#define IMG_DYNABOMB_PLAYER_2_ACTIVE			595
#define IMG_DYNABOMB_PLAYER_3				596
#define IMG_DYNABOMB_PLAYER_3_ACTIVE			597
#define IMG_DYNABOMB_PLAYER_4				598
#define IMG_DYNABOMB_PLAYER_4_ACTIVE			599
#define IMG_DYNABOMB_INCREASE_NUMBER			600
#define IMG_DYNABOMB_INCREASE_NUMBER_COLLECTING		601
#define IMG_DYNABOMB_INCREASE_SIZE			602
#define IMG_DYNABOMB_INCREASE_SIZE_COLLECTING		603
#define IMG_DYNABOMB_INCREASE_POWER			604
#define IMG_DYNABOMB_INCREASE_POWER_COLLECTING		605
#define IMG_PIG						606
#define IMG_PIG_DOWN					607
#define IMG_PIG_UP					608
#define IMG_PIG_LEFT					609
#define IMG_PIG_RIGHT					610
#define IMG_PIG_MOVING_DOWN				611
#define IMG_PIG_MOVING_UP				612
#define IMG_PIG_MOVING_LEFT				613
#define IMG_PIG_MOVING_RIGHT				614
#define IMG_PIG_DIGGING_DOWN				615
#define IMG_PIG_DIGGING_UP				616
#define IMG_PIG_DIGGING_LEFT				617
#define IMG_PIG_DIGGING_RIGHT				618
#define IMG_DRAGON					619
#define IMG_DRAGON_DOWN					620
#define IMG_DRAGON_UP					621
#define IMG_DRAGON_LEFT					622
#define IMG_DRAGON_RIGHT				623
#define IMG_DRAGON_MOVING_DOWN				624
#define IMG_DRAGON_MOVING_UP				625
#define IMG_DRAGON_MOVING_LEFT				626
#define IMG_DRAGON_MOVING_RIGHT				627
#define IMG_DRAGON_ATTACKING_DOWN			628
#define IMG_DRAGON_ATTACKING_UP				629
#define IMG_DRAGON_ATTACKING_LEFT			630
#define IMG_DRAGON_ATTACKING_RIGHT			631
#define IMG_MOLE					632
#define IMG_MOLE_DOWN					633
#define IMG_MOLE_UP					634
#define IMG_MOLE_LEFT					635
#define IMG_MOLE_RIGHT					636
#define IMG_MOLE_MOVING_DOWN				637
#define IMG_MOLE_MOVING_UP				638
#define IMG_MOLE_MOVING_LEFT				639
#define IMG_MOLE_MOVING_RIGHT				640
#define IMG_MOLE_DIGGING_DOWN				641
#define IMG_MOLE_DIGGING_UP				642
#define IMG_MOLE_DIGGING_LEFT				643
#define IMG_MOLE_DIGGING_RIGHT				644
#define IMG_PENGUIN					645
#define IMG_PENGUIN_DOWN				646
#define IMG_PENGUIN_UP					647
#define IMG_PENGUIN_LEFT				648
#define IMG_PENGUIN_RIGHT				649
#define IMG_PENGUIN_MOVING_DOWN				650
#define IMG_PENGUIN_MOVING_UP				651
#define IMG_PENGUIN_MOVING_LEFT				652
#define IMG_PENGUIN_MOVING_RIGHT			653
#define IMG_SATELLITE					654
#define IMG_FLAMES_1_LEFT				655
#define IMG_FLAMES_2_LEFT				656
#define IMG_FLAMES_3_LEFT				657
#define IMG_FLAMES_1_RIGHT				658
#define IMG_FLAMES_2_RIGHT				659
#define IMG_FLAMES_3_RIGHT				660
#define IMG_FLAMES_1_UP					661
#define IMG_FLAMES_2_UP					662
#define IMG_FLAMES_3_UP					663
#define IMG_FLAMES_1_DOWN				664
#define IMG_FLAMES_2_DOWN				665
#define IMG_FLAMES_3_DOWN				666
#define IMG_STONEBLOCK					667
#define IMG_PLAYER_1					668
#define IMG_PLAYER_1_DOWN				669
#define IMG_PLAYER_1_UP					670
#define IMG_PLAYER_1_LEFT				671
#define IMG_PLAYER_1_RIGHT				672
#define IMG_PLAYER_1_MOVING_DOWN			673
#define IMG_PLAYER_1_MOVING_UP				674
#define IMG_PLAYER_1_MOVING_LEFT			675
#define IMG_PLAYER_1_MOVING_RIGHT			676
#define IMG_PLAYER_1_DIGGING_DOWN			677
#define IMG_PLAYER_1_DIGGING_UP				678
#define IMG_PLAYER_1_DIGGING_LEFT			679
#define IMG_PLAYER_1_DIGGING_RIGHT			680
#define IMG_PLAYER_1_COLLECTING_DOWN			681
#define IMG_PLAYER_1_COLLECTING_UP			682
#define IMG_PLAYER_1_COLLECTING_LEFT			683
#define IMG_PLAYER_1_COLLECTING_RIGHT			684
#define IMG_PLAYER_1_PUSHING_DOWN			685
#define IMG_PLAYER_1_PUSHING_UP				686
#define IMG_PLAYER_1_PUSHING_LEFT			687
#define IMG_PLAYER_1_PUSHING_RIGHT			688
#define IMG_PLAYER_1_SNAPPING_DOWN			689
#define IMG_PLAYER_1_SNAPPING_UP			690
#define IMG_PLAYER_1_SNAPPING_LEFT			691
#define IMG_PLAYER_1_SNAPPING_RIGHT			692
#define IMG_PLAYER_2					693
#define IMG_PLAYER_2_DOWN				694
#define IMG_PLAYER_2_UP					695
#define IMG_PLAYER_2_LEFT				696
#define IMG_PLAYER_2_RIGHT				697
#define IMG_PLAYER_2_MOVING_DOWN			698
#define IMG_PLAYER_2_MOVING_UP				699
#define IMG_PLAYER_2_MOVING_LEFT			700
#define IMG_PLAYER_2_MOVING_RIGHT			701
#define IMG_PLAYER_2_DIGGING_DOWN			702
#define IMG_PLAYER_2_DIGGING_UP				703
#define IMG_PLAYER_2_DIGGING_LEFT			704
#define IMG_PLAYER_2_DIGGING_RIGHT			705
#define IMG_PLAYER_2_COLLECTING_DOWN			706
#define IMG_PLAYER_2_COLLECTING_UP			707
#define IMG_PLAYER_2_COLLECTING_LEFT			708
#define IMG_PLAYER_2_COLLECTING_RIGHT			709
#define IMG_PLAYER_2_PUSHING_DOWN			710
#define IMG_PLAYER_2_PUSHING_UP				711
#define IMG_PLAYER_2_PUSHING_LEFT			712
#define IMG_PLAYER_2_PUSHING_RIGHT			713
#define IMG_PLAYER_2_SNAPPING_DOWN			714
#define IMG_PLAYER_2_SNAPPING_UP			715
#define IMG_PLAYER_2_SNAPPING_LEFT			716
#define IMG_PLAYER_2_SNAPPING_RIGHT			717
#define IMG_PLAYER_3					718
#define IMG_PLAYER_3_DOWN				719
#define IMG_PLAYER_3_UP					720
#define IMG_PLAYER_3_LEFT				721
#define IMG_PLAYER_3_RIGHT				722
#define IMG_PLAYER_3_MOVING_DOWN			723
#define IMG_PLAYER_3_MOVING_UP				724
#define IMG_PLAYER_3_MOVING_LEFT			725
#define IMG_PLAYER_3_MOVING_RIGHT			726
#define IMG_PLAYER_3_DIGGING_DOWN			727
#define IMG_PLAYER_3_DIGGING_UP				728
#define IMG_PLAYER_3_DIGGING_LEFT			729
#define IMG_PLAYER_3_DIGGING_RIGHT			730
#define IMG_PLAYER_3_COLLECTING_DOWN			731
#define IMG_PLAYER_3_COLLECTING_UP			732
#define IMG_PLAYER_3_COLLECTING_LEFT			733
#define IMG_PLAYER_3_COLLECTING_RIGHT			734
#define IMG_PLAYER_3_PUSHING_DOWN			735
#define IMG_PLAYER_3_PUSHING_UP				736
#define IMG_PLAYER_3_PUSHING_LEFT			737
#define IMG_PLAYER_3_PUSHING_RIGHT			738
#define IMG_PLAYER_3_SNAPPING_DOWN			739
#define IMG_PLAYER_3_SNAPPING_UP			740
#define IMG_PLAYER_3_SNAPPING_LEFT			741
#define IMG_PLAYER_3_SNAPPING_RIGHT			742
#define IMG_PLAYER_4					743
#define IMG_PLAYER_4_DOWN				744
#define IMG_PLAYER_4_UP					745
#define IMG_PLAYER_4_LEFT				746
#define IMG_PLAYER_4_RIGHT				747
#define IMG_PLAYER_4_MOVING_DOWN			748
#define IMG_PLAYER_4_MOVING_UP				749
#define IMG_PLAYER_4_MOVING_LEFT			750
#define IMG_PLAYER_4_MOVING_RIGHT			751
#define IMG_PLAYER_4_DIGGING_DOWN			752
#define IMG_PLAYER_4_DIGGING_UP				753
#define IMG_PLAYER_4_DIGGING_LEFT			754
#define IMG_PLAYER_4_DIGGING_RIGHT			755
#define IMG_PLAYER_4_COLLECTING_DOWN			756
#define IMG_PLAYER_4_COLLECTING_UP			757
#define IMG_PLAYER_4_COLLECTING_LEFT			758
#define IMG_PLAYER_4_COLLECTING_RIGHT			759
#define IMG_PLAYER_4_PUSHING_DOWN			760
#define IMG_PLAYER_4_PUSHING_UP				761
#define IMG_PLAYER_4_PUSHING_LEFT			762
#define IMG_PLAYER_4_PUSHING_RIGHT			763
#define IMG_PLAYER_4_SNAPPING_DOWN			764
#define IMG_PLAYER_4_SNAPPING_UP			765
#define IMG_PLAYER_4_SNAPPING_LEFT			766
#define IMG_PLAYER_4_SNAPPING_RIGHT			767
#define IMG_DEFAULT_EXPLODING				768
#define IMG_TWINKLE_BLUE				769
#define IMG_TWINKLE_WHITE				770
#define IMG_STEELWALL_TOPLEFT				771
#define IMG_STEELWALL_TOPRIGHT				772
#define IMG_STEELWALL_BOTTOMLEFT			773
#define IMG_STEELWALL_BOTTOMRIGHT			774
#define IMG_STEELWALL_HORIZONTAL			775
#define IMG_STEELWALL_VERTICAL				776
#define IMG_STEELWALL_TOPLEFT_EDITOR			777
#define IMG_STEELWALL_TOPRIGHT_EDITOR			778
#define IMG_STEELWALL_BOTTOMLEFT_EDITOR			779
#define IMG_STEELWALL_BOTTOMRIGHT_EDITOR		780
#define IMG_STEELWALL_HORIZONTAL_EDITOR			781
#define IMG_STEELWALL_VERTICAL_EDITOR			782
#define IMG_INVISIBLE_STEELWALL_TOPLEFT			783
#define IMG_INVISIBLE_STEELWALL_TOPRIGHT		784
#define IMG_INVISIBLE_STEELWALL_BOTTOMLEFT		785
#define IMG_INVISIBLE_STEELWALL_BOTTOMRIGHT		786
#define IMG_INVISIBLE_STEELWALL_HORIZONTAL		787
#define IMG_INVISIBLE_STEELWALL_VERTICAL		788
#define IMG_INVISIBLE_STEELWALL_TOPLEFT_EDITOR		789
#define IMG_INVISIBLE_STEELWALL_TOPRIGHT_EDITOR		790
#define IMG_INVISIBLE_STEELWALL_BOTTOMLEFT_EDITOR	791
#define IMG_INVISIBLE_STEELWALL_BOTTOMRIGHT_EDITOR	792
#define IMG_INVISIBLE_STEELWALL_HORIZONTAL_EDITOR	793
#define IMG_INVISIBLE_STEELWALL_VERTICAL_EDITOR		794
#define IMG_ARROW_LEFT					795
#define IMG_ARROW_RIGHT					796
#define IMG_ARROW_UP					797
#define IMG_ARROW_DOWN					798
#define IMG_UNKNOWN					799
#define IMG_TRIGGER_ELEMENT				800
#define IMG_TRIGGER_PLAYER				801
#define IMG_TRIGGER_CE_VALUE				802
#define IMG_TRIGGER_CE_SCORE				803
#define IMG_CURRENT_CE_VALUE				804
#define IMG_CURRENT_CE_SCORE				805
#define IMG_PREV_CE_1					806
#define IMG_PREV_CE_2					807
#define IMG_PREV_CE_3					808
#define IMG_PREV_CE_4					809
#define IMG_PREV_CE_5					810
#define IMG_PREV_CE_6					811
#define IMG_PREV_CE_7					812
#define IMG_PREV_CE_8					813
#define IMG_NEXT_CE_1					814
#define IMG_NEXT_CE_2					815
#define IMG_NEXT_CE_3					816
#define IMG_NEXT_CE_4					817
#define IMG_NEXT_CE_5					818
#define IMG_NEXT_CE_6					819
#define IMG_NEXT_CE_7					820
#define IMG_NEXT_CE_8					821
#define IMG_SELF					822
#define IMG_ANY_ELEMENT					823
#define IMG_EMC_KEY_5					824
#define IMG_EMC_KEY_5_COLLECTING			825
#define IMG_EMC_KEY_6					826
#define IMG_EMC_KEY_6_COLLECTING			827
#define IMG_EMC_KEY_7					828
#define IMG_EMC_KEY_7_COLLECTING			829
#define IMG_EMC_KEY_8					830
#define IMG_EMC_KEY_8_COLLECTING			831
#define IMG_EMC_GATE_5					832
#define IMG_EMC_GATE_6					833
#define IMG_EMC_GATE_7					834
#define IMG_EMC_GATE_8					835
#define IMG_EMC_GATE_5_GRAY				836
#define IMG_EMC_GATE_5_GRAY_EDITOR			837
#define IMG_EMC_GATE_5_GRAY_ACTIVE			838
#define IMG_EMC_GATE_6_GRAY				839
#define IMG_EMC_GATE_6_GRAY_EDITOR			840
#define IMG_EMC_GATE_6_GRAY_ACTIVE			841
#define IMG_EMC_GATE_7_GRAY				842
#define IMG_EMC_GATE_7_GRAY_EDITOR			843
#define IMG_EMC_GATE_7_GRAY_ACTIVE			844
#define IMG_EMC_GATE_8_GRAY				845
#define IMG_EMC_GATE_8_GRAY_EDITOR			846
#define IMG_EMC_GATE_8_GRAY_ACTIVE			847
#define IMG_EMC_ANDROID					848
#define IMG_EMC_ANDROID_SHRINKING_UPLEFT		849
#define IMG_EMC_ANDROID_GROWING_DOWNRIGHT		850
#define IMG_EMC_ANDROID_SHRINKING_DOWNLEFT		851
#define IMG_EMC_ANDROID_GROWING_UPRIGHT			852
#define IMG_EMC_ANDROID_SHRINKING_UPRIGHT		853
#define IMG_EMC_ANDROID_GROWING_DOWNLEFT		854
#define IMG_EMC_ANDROID_SHRINKING_DOWNRIGHT		855
#define IMG_EMC_ANDROID_GROWING_UPLEFT			856
#define IMG_EMC_GRASS					857
#define IMG_EMC_GRASS_CRUMBLED				858
#define IMG_EMC_GRASS_DIGGING_LEFT			859
#define IMG_EMC_GRASS_DIGGING_RIGHT			860
#define IMG_EMC_GRASS_DIGGING_UP			861
#define IMG_EMC_GRASS_DIGGING_DOWN			862
#define IMG_EMC_GRASS_DIGGING_LEFT_CRUMBLED		863
#define IMG_EMC_GRASS_DIGGING_RIGHT_CRUMBLED		864
#define IMG_EMC_GRASS_DIGGING_UP_CRUMBLED		865
#define IMG_EMC_GRASS_DIGGING_DOWN_CRUMBLED		866
#define IMG_EMC_MAGIC_BALL				867
#define IMG_EMC_MAGIC_BALL_ACTIVE			868
#define IMG_EMC_MAGIC_BALL_DROPPING			869
#define IMG_EMC_MAGIC_BALL_SWITCH			870
#define IMG_EMC_MAGIC_BALL_SWITCH_ACTIVE		871
#define IMG_EMC_SPRING_BUMPER				872
#define IMG_EMC_SPRING_BUMPER_ACTIVE			873
#define IMG_EMC_PLANT					874
#define IMG_EMC_PLANT_CRUMBLED				875
#define IMG_EMC_LENSES					876
#define IMG_EMC_LENSES_COLLECTING			877
#define IMG_EMC_MAGNIFIER				878
#define IMG_EMC_MAGNIFIER_COLLECTING			879
#define IMG_EMC_WALL_9					880
#define IMG_EMC_WALL_10					881
#define IMG_EMC_WALL_11					882
#define IMG_EMC_WALL_12					883
#define IMG_EMC_WALL_13					884
#define IMG_EMC_WALL_14					885
#define IMG_EMC_WALL_15					886
#define IMG_EMC_WALL_16					887
#define IMG_EMC_WALL_SLIPPERY_1				888
#define IMG_EMC_WALL_SLIPPERY_2				889
#define IMG_EMC_WALL_SLIPPERY_3				890
#define IMG_EMC_WALL_SLIPPERY_4				891
#define IMG_EMC_FAKE_GRASS				892
#define IMG_EMC_FAKE_GRASS_CRUMBLED			893
#define IMG_EMC_FAKE_GRASS_ACTIVE			894
#define IMG_EMC_FAKE_GRASS_ACTIVE_CRUMBLED		895
#define IMG_EMC_FAKE_GRASS_EDITOR			896
#define IMG_EMC_FAKE_ACID				897
#define IMG_EMC_DRIPPER					898
#define IMG_EMC_DRIPPER_EDITOR				899
#define IMG_EMC_DRIPPER_ACTIVE				900
#define IMG_MM_MCDUFFIN					901
#define IMG_MM_MCDUFFIN_RIGHT				902
#define IMG_MM_MCDUFFIN_UP				903
#define IMG_MM_MCDUFFIN_LEFT				904
#define IMG_MM_MCDUFFIN_DOWN				905
#define IMG_MM_EXIT_CLOSED				906
#define IMG_MM_EXIT_OPENING				907
#define IMG_MM_EXIT_OPEN				908
#define IMG_MM_EXIT_CLOSING				909
#define IMG_MM_MIRROR_1					910
#define IMG_MM_MIRROR_2					911
#define IMG_MM_MIRROR_3					912
#define IMG_MM_MIRROR_4					913
#define IMG_MM_MIRROR_5					914
#define IMG_MM_MIRROR_6					915
#define IMG_MM_MIRROR_7					916
#define IMG_MM_MIRROR_8					917
#define IMG_MM_MIRROR_9					918
#define IMG_MM_MIRROR_10				919
#define IMG_MM_MIRROR_11				920
#define IMG_MM_MIRROR_12				921
#define IMG_MM_MIRROR_13				922
#define IMG_MM_MIRROR_14				923
#define IMG_MM_MIRROR_15				924
#define IMG_MM_MIRROR_16				925
#define IMG_MM_MIRROR_FIXED_1				926
#define IMG_MM_MIRROR_FIXED_2				927
#define IMG_MM_MIRROR_FIXED_3				928
#define IMG_MM_MIRROR_FIXED_4				929
#define IMG_MM_STEEL_GRID_FIXED_1			930
#define IMG_MM_STEEL_GRID_FIXED_2			931
#define IMG_MM_STEEL_GRID_FIXED_3			932
#define IMG_MM_STEEL_GRID_FIXED_4			933
#define IMG_MM_WOODEN_GRID_FIXED_1			934
#define IMG_MM_WOODEN_GRID_FIXED_2			935
#define IMG_MM_WOODEN_GRID_FIXED_3			936
#define IMG_MM_WOODEN_GRID_FIXED_4			937
#define IMG_MM_POLARIZER_1				938
#define IMG_MM_POLARIZER_2				939
#define IMG_MM_POLARIZER_3				940
#define IMG_MM_POLARIZER_4				941
#define IMG_MM_POLARIZER_5				942
#define IMG_MM_POLARIZER_6				943
#define IMG_MM_POLARIZER_7				944
#define IMG_MM_POLARIZER_8				945
#define IMG_MM_POLARIZER_9				946
#define IMG_MM_POLARIZER_10				947
#define IMG_MM_POLARIZER_11				948
#define IMG_MM_POLARIZER_12				949
#define IMG_MM_POLARIZER_13				950
#define IMG_MM_POLARIZER_14				951
#define IMG_MM_POLARIZER_15				952
#define IMG_MM_POLARIZER_16				953
#define IMG_MM_POLARIZER_CROSS_1			954
#define IMG_MM_POLARIZER_CROSS_2			955
#define IMG_MM_POLARIZER_CROSS_3			956
#define IMG_MM_POLARIZER_CROSS_4			957
#define IMG_MM_TELEPORTER_1				958
#define IMG_MM_TELEPORTER_2				959
#define IMG_MM_TELEPORTER_3				960
#define IMG_MM_TELEPORTER_4				961
#define IMG_MM_TELEPORTER_5				962
#define IMG_MM_TELEPORTER_6				963
#define IMG_MM_TELEPORTER_7				964
#define IMG_MM_TELEPORTER_8				965
#define IMG_MM_TELEPORTER_9				966
#define IMG_MM_TELEPORTER_10				967
#define IMG_MM_TELEPORTER_11				968
#define IMG_MM_TELEPORTER_12				969
#define IMG_MM_TELEPORTER_13				970
#define IMG_MM_TELEPORTER_14				971
#define IMG_MM_TELEPORTER_15				972
#define IMG_MM_TELEPORTER_16				973
#define IMG_MM_TELEPORTER_RED_1				974
#define IMG_MM_TELEPORTER_RED_2				975
#define IMG_MM_TELEPORTER_RED_3				976
#define IMG_MM_TELEPORTER_RED_4				977
#define IMG_MM_TELEPORTER_RED_5				978
#define IMG_MM_TELEPORTER_RED_6				979
#define IMG_MM_TELEPORTER_RED_7				980
#define IMG_MM_TELEPORTER_RED_8				981
#define IMG_MM_TELEPORTER_RED_9				982
#define IMG_MM_TELEPORTER_RED_10			983
#define IMG_MM_TELEPORTER_RED_11			984
#define IMG_MM_TELEPORTER_RED_12			985
#define IMG_MM_TELEPORTER_RED_13			986
#define IMG_MM_TELEPORTER_RED_14			987
#define IMG_MM_TELEPORTER_RED_15			988
#define IMG_MM_TELEPORTER_RED_16			989
#define IMG_MM_TELEPORTER_YELLOW_1			990
#define IMG_MM_TELEPORTER_YELLOW_2			991
#define IMG_MM_TELEPORTER_YELLOW_3			992
#define IMG_MM_TELEPORTER_YELLOW_4			993
#define IMG_MM_TELEPORTER_YELLOW_5			994
#define IMG_MM_TELEPORTER_YELLOW_6			995
#define IMG_MM_TELEPORTER_YELLOW_7			996
#define IMG_MM_TELEPORTER_YELLOW_8			997
#define IMG_MM_TELEPORTER_YELLOW_9			998
#define IMG_MM_TELEPORTER_YELLOW_10			999
#define IMG_MM_TELEPORTER_YELLOW_11			1000
#define IMG_MM_TELEPORTER_YELLOW_12			1001
#define IMG_MM_TELEPORTER_YELLOW_13			1002
#define IMG_MM_TELEPORTER_YELLOW_14			1003
#define IMG_MM_TELEPORTER_YELLOW_15			1004
#define IMG_MM_TELEPORTER_YELLOW_16			1005
#define IMG_MM_TELEPORTER_GREEN_1			1006
#define IMG_MM_TELEPORTER_GREEN_2			1007
#define IMG_MM_TELEPORTER_GREEN_3			1008
#define IMG_MM_TELEPORTER_GREEN_4			1009
#define IMG_MM_TELEPORTER_GREEN_5			1010
#define IMG_MM_TELEPORTER_GREEN_6			1011
#define IMG_MM_TELEPORTER_GREEN_7			1012
#define IMG_MM_TELEPORTER_GREEN_8			1013
#define IMG_MM_TELEPORTER_GREEN_9			1014
#define IMG_MM_TELEPORTER_GREEN_10			1015
#define IMG_MM_TELEPORTER_GREEN_11			1016
#define IMG_MM_TELEPORTER_GREEN_12			1017
#define IMG_MM_TELEPORTER_GREEN_13			1018
#define IMG_MM_TELEPORTER_GREEN_14			1019
#define IMG_MM_TELEPORTER_GREEN_15			1020
#define IMG_MM_TELEPORTER_GREEN_16			1021
#define IMG_MM_TELEPORTER_BLUE_1			1022
#define IMG_MM_TELEPORTER_BLUE_2			1023
#define IMG_MM_TELEPORTER_BLUE_3			1024
#define IMG_MM_TELEPORTER_BLUE_4			1025
#define IMG_MM_TELEPORTER_BLUE_5			1026
#define IMG_MM_TELEPORTER_BLUE_6			1027
#define IMG_MM_TELEPORTER_BLUE_7			1028
#define IMG_MM_TELEPORTER_BLUE_8			1029
#define IMG_MM_TELEPORTER_BLUE_9			1030
#define IMG_MM_TELEPORTER_BLUE_10			1031
#define IMG_MM_TELEPORTER_BLUE_11			1032
#define IMG_MM_TELEPORTER_BLUE_12			1033
#define IMG_MM_TELEPORTER_BLUE_13			1034
#define IMG_MM_TELEPORTER_BLUE_14			1035
#define IMG_MM_TELEPORTER_BLUE_15			1036
#define IMG_MM_TELEPORTER_BLUE_16			1037
#define IMG_MM_KETTLE					1038
#define IMG_MM_KETTLE_EXPLODING				1039
#define IMG_MM_BOMB					1040
#define IMG_MM_BOMB_ACTIVE				1041
#define IMG_MM_PRISM					1042
#define IMG_MM_FUSE					1043
#define IMG_MM_FUSE_ACTIVE				1044
#define IMG_MM_STEEL_LOCK				1045
#define IMG_MM_STEEL_LOCK_EXPLODING			1046
#define IMG_MM_WOODEN_LOCK				1047
#define IMG_MM_WOODEN_LOCK_EXPLODING			1048
#define IMG_MM_STEEL_BLOCK				1049
#define IMG_MM_WOODEN_BLOCK				1050
#define IMG_MM_KEY					1051
#define IMG_MM_LIGHTBULB				1052
#define IMG_MM_LIGHTBULB_ACTIVE				1053
#define IMG_MM_LIGHTBALL				1054
#define IMG_MM_LIGHTBALL_RED				1055
#define IMG_MM_LIGHTBALL_BLUE				1056
#define IMG_MM_LIGHTBALL_YELLOW				1057
#define IMG_MM_GRAY_BALL				1058
#define IMG_MM_GRAY_BALL_ACTIVE				1059
#define IMG_MM_GRAY_BALL_EDITOR				1060
#define IMG_MM_FUEL_FULL				1061
#define IMG_MM_FUEL_EMPTY				1062
#define IMG_MM_STEEL_WALL				1063
#define IMG_MM_WOODEN_WALL				1064
#define IMG_MM_ICE_WALL					1065
#define IMG_MM_ICE_WALL_SHRINKING			1066
#define IMG_MM_AMOEBA_WALL				1067
#define IMG_MM_AMOEBA_WALL_GROWING			1068
#define IMG_MM_PACMAN					1069
#define IMG_MM_PACMAN_RIGHT				1070
#define IMG_MM_PACMAN_UP				1071
#define IMG_MM_PACMAN_LEFT				1072
#define IMG_MM_PACMAN_DOWN				1073
#define IMG_MM_PACMAN_EATING_RIGHT			1074
#define IMG_MM_PACMAN_EATING_UP				1075
#define IMG_MM_PACMAN_EATING_LEFT			1076
#define IMG_MM_PACMAN_EATING_DOWN			1077
#define IMG_MM_ENVELOPE_1				1078
#define IMG_MM_ENVELOPE_1_COLLECTING			1079
#define IMG_MM_ENVELOPE_2				1080
#define IMG_MM_ENVELOPE_2_COLLECTING			1081
#define IMG_MM_ENVELOPE_3				1082
#define IMG_MM_ENVELOPE_3_COLLECTING			1083
#define IMG_MM_ENVELOPE_4				1084
#define IMG_MM_ENVELOPE_4_COLLECTING			1085
#define IMG_MM_DEFAULT_EXPLODING			1086
#define IMG_DF_LASER					1087
#define IMG_DF_LASER_RIGHT				1088
#define IMG_DF_LASER_UP					1089
#define IMG_DF_LASER_LEFT				1090
#define IMG_DF_LASER_DOWN				1091
#define IMG_DF_RECEIVER					1092
#define IMG_DF_RECEIVER_RIGHT				1093
#define IMG_DF_RECEIVER_UP				1094
#define IMG_DF_RECEIVER_LEFT				1095
#define IMG_DF_RECEIVER_DOWN				1096
#define IMG_DF_MIRROR_1					1097
#define IMG_DF_MIRROR_2					1098
#define IMG_DF_MIRROR_3					1099
#define IMG_DF_MIRROR_4					1100
#define IMG_DF_MIRROR_5					1101
#define IMG_DF_MIRROR_6					1102
#define IMG_DF_MIRROR_7					1103
#define IMG_DF_MIRROR_8					1104
#define IMG_DF_MIRROR_9					1105
#define IMG_DF_MIRROR_10				1106
#define IMG_DF_MIRROR_11				1107
#define IMG_DF_MIRROR_12				1108
#define IMG_DF_MIRROR_13				1109
#define IMG_DF_MIRROR_14				1110
#define IMG_DF_MIRROR_15				1111
#define IMG_DF_MIRROR_16				1112
#define IMG_DF_MIRROR_ROTATING_1			1113
#define IMG_DF_MIRROR_ROTATING_1_EDITOR			1114
#define IMG_DF_MIRROR_ROTATING_2			1115
#define IMG_DF_MIRROR_ROTATING_2_EDITOR			1116
#define IMG_DF_MIRROR_ROTATING_3			1117
#define IMG_DF_MIRROR_ROTATING_3_EDITOR			1118
#define IMG_DF_MIRROR_ROTATING_4			1119
#define IMG_DF_MIRROR_ROTATING_4_EDITOR			1120
#define IMG_DF_MIRROR_ROTATING_5			1121
#define IMG_DF_MIRROR_ROTATING_5_EDITOR			1122
#define IMG_DF_MIRROR_ROTATING_6			1123
#define IMG_DF_MIRROR_ROTATING_6_EDITOR			1124
#define IMG_DF_MIRROR_ROTATING_7			1125
#define IMG_DF_MIRROR_ROTATING_7_EDITOR			1126
#define IMG_DF_MIRROR_ROTATING_8			1127
#define IMG_DF_MIRROR_ROTATING_8_EDITOR			1128
#define IMG_DF_MIRROR_ROTATING_9			1129
#define IMG_DF_MIRROR_ROTATING_9_EDITOR			1130
#define IMG_DF_MIRROR_ROTATING_10			1131
#define IMG_DF_MIRROR_ROTATING_10_EDITOR		1132
#define IMG_DF_MIRROR_ROTATING_11			1133
#define IMG_DF_MIRROR_ROTATING_11_EDITOR		1134
#define IMG_DF_MIRROR_ROTATING_12			1135
#define IMG_DF_MIRROR_ROTATING_12_EDITOR		1136
#define IMG_DF_MIRROR_ROTATING_13			1137
#define IMG_DF_MIRROR_ROTATING_13_EDITOR		1138
#define IMG_DF_MIRROR_ROTATING_14			1139
#define IMG_DF_MIRROR_ROTATING_14_EDITOR		1140
#define IMG_DF_MIRROR_ROTATING_15			1141
#define IMG_DF_MIRROR_ROTATING_15_EDITOR		1142
#define IMG_DF_MIRROR_ROTATING_16			1143
#define IMG_DF_MIRROR_ROTATING_16_EDITOR		1144
#define IMG_DF_STEEL_GRID_FIXED_1			1145
#define IMG_DF_STEEL_GRID_FIXED_2			1146
#define IMG_DF_STEEL_GRID_FIXED_3			1147
#define IMG_DF_STEEL_GRID_FIXED_4			1148
#define IMG_DF_STEEL_GRID_FIXED_5			1149
#define IMG_DF_STEEL_GRID_FIXED_6			1150
#define IMG_DF_STEEL_GRID_FIXED_7			1151
#define IMG_DF_STEEL_GRID_FIXED_8			1152
#define IMG_DF_WOODEN_GRID_FIXED_1			1153
#define IMG_DF_WOODEN_GRID_FIXED_2			1154
#define IMG_DF_WOODEN_GRID_FIXED_3			1155
#define IMG_DF_WOODEN_GRID_FIXED_4			1156
#define IMG_DF_WOODEN_GRID_FIXED_5			1157
#define IMG_DF_WOODEN_GRID_FIXED_6			1158
#define IMG_DF_WOODEN_GRID_FIXED_7			1159
#define IMG_DF_WOODEN_GRID_FIXED_8			1160
#define IMG_DF_STEEL_GRID_ROTATING_1			1161
#define IMG_DF_STEEL_GRID_ROTATING_1_EDITOR		1162
#define IMG_DF_STEEL_GRID_ROTATING_2			1163
#define IMG_DF_STEEL_GRID_ROTATING_2_EDITOR		1164
#define IMG_DF_STEEL_GRID_ROTATING_3			1165
#define IMG_DF_STEEL_GRID_ROTATING_3_EDITOR		1166
#define IMG_DF_STEEL_GRID_ROTATING_4			1167
#define IMG_DF_STEEL_GRID_ROTATING_4_EDITOR		1168
#define IMG_DF_STEEL_GRID_ROTATING_5			1169
#define IMG_DF_STEEL_GRID_ROTATING_5_EDITOR		1170
#define IMG_DF_STEEL_GRID_ROTATING_6			1171
#define IMG_DF_STEEL_GRID_ROTATING_6_EDITOR		1172
#define IMG_DF_STEEL_GRID_ROTATING_7			1173
#define IMG_DF_STEEL_GRID_ROTATING_7_EDITOR		1174
#define IMG_DF_STEEL_GRID_ROTATING_8			1175
#define IMG_DF_STEEL_GRID_ROTATING_8_EDITOR		1176
#define IMG_DF_WOODEN_GRID_ROTATING_1			1177
#define IMG_DF_WOODEN_GRID_ROTATING_1_EDITOR		1178
#define IMG_DF_WOODEN_GRID_ROTATING_2			1179
#define IMG_DF_WOODEN_GRID_ROTATING_2_EDITOR		1180
#define IMG_DF_WOODEN_GRID_ROTATING_3			1181
#define IMG_DF_WOODEN_GRID_ROTATING_3_EDITOR		1182
#define IMG_DF_WOODEN_GRID_ROTATING_4			1183
#define IMG_DF_WOODEN_GRID_ROTATING_4_EDITOR		1184
#define IMG_DF_WOODEN_GRID_ROTATING_5			1185
#define IMG_DF_WOODEN_GRID_ROTATING_5_EDITOR		1186
#define IMG_DF_WOODEN_GRID_ROTATING_6			1187
#define IMG_DF_WOODEN_GRID_ROTATING_6_EDITOR		1188
#define IMG_DF_WOODEN_GRID_ROTATING_7			1189
#define IMG_DF_WOODEN_GRID_ROTATING_7_EDITOR		1190
#define IMG_DF_WOODEN_GRID_ROTATING_8			1191
#define IMG_DF_WOODEN_GRID_ROTATING_8_EDITOR		1192
#define IMG_DF_FIBRE_OPTIC_RED_1			1193
#define IMG_DF_FIBRE_OPTIC_RED_1_EDITOR			1194
#define IMG_DF_FIBRE_OPTIC_RED_2			1195
#define IMG_DF_FIBRE_OPTIC_RED_2_EDITOR			1196
#define IMG_DF_FIBRE_OPTIC_YELLOW_1			1197
#define IMG_DF_FIBRE_OPTIC_YELLOW_1_EDITOR		1198
#define IMG_DF_FIBRE_OPTIC_YELLOW_2			1199
#define IMG_DF_FIBRE_OPTIC_YELLOW_2_EDITOR		1200
#define IMG_DF_FIBRE_OPTIC_GREEN_1			1201
#define IMG_DF_FIBRE_OPTIC_GREEN_1_EDITOR		1202
#define IMG_DF_FIBRE_OPTIC_GREEN_2			1203
#define IMG_DF_FIBRE_OPTIC_GREEN_2_EDITOR		1204
#define IMG_DF_FIBRE_OPTIC_BLUE_1			1205
#define IMG_DF_FIBRE_OPTIC_BLUE_1_EDITOR		1206
#define IMG_DF_FIBRE_OPTIC_BLUE_2			1207
#define IMG_DF_FIBRE_OPTIC_BLUE_2_EDITOR		1208
#define IMG_DF_STEEL_WALL				1209
#define IMG_DF_WOODEN_WALL				1210
#define IMG_DF_REFRACTOR				1211
#define IMG_DF_CELL					1212
#define IMG_DF_MINE					1213
#define IMG_DF_MINE_ACTIVE				1214
#define IMG_DF_MIRROR_FIXED_1				1215
#define IMG_DF_MIRROR_FIXED_2				1216
#define IMG_DF_MIRROR_FIXED_3				1217
#define IMG_DF_MIRROR_FIXED_4				1218
#define IMG_DF_MIRROR_FIXED_5				1219
#define IMG_DF_MIRROR_FIXED_6				1220
#define IMG_DF_MIRROR_FIXED_7				1221
#define IMG_DF_MIRROR_FIXED_8				1222
#define IMG_DF_MIRROR_FIXED_9				1223
#define IMG_DF_MIRROR_FIXED_10				1224
#define IMG_DF_MIRROR_FIXED_11				1225
#define IMG_DF_MIRROR_FIXED_12				1226
#define IMG_DF_MIRROR_FIXED_13				1227
#define IMG_DF_MIRROR_FIXED_14				1228
#define IMG_DF_MIRROR_FIXED_15				1229
#define IMG_DF_MIRROR_FIXED_16				1230
#define IMG_DF_SLOPE_1					1231
#define IMG_DF_SLOPE_2					1232
#define IMG_DF_SLOPE_3					1233
#define IMG_DF_SLOPE_4					1234
#define IMG_GRAPHIC_1					1235
#define IMG_GRAPHIC_2					1236
#define IMG_GRAPHIC_3					1237
#define IMG_GRAPHIC_4					1238
#define IMG_GRAPHIC_5					1239
#define IMG_GRAPHIC_6					1240
#define IMG_GRAPHIC_7					1241
#define IMG_GRAPHIC_8					1242
#define IMG_CHAR_SPACE					1243
#define IMG_CHAR_SPACE_EDITOR				1244
#define IMG_CHAR_EXCLAM					1245
#define IMG_CHAR_QUOTEDBL				1246
#define IMG_CHAR_NUMBERSIGN				1247
#define IMG_CHAR_DOLLAR					1248
#define IMG_CHAR_PERCENT				1249
#define IMG_CHAR_AMPERSAND				1250
#define IMG_CHAR_APOSTROPHE				1251
#define IMG_CHAR_PARENLEFT				1252
#define IMG_CHAR_PARENRIGHT				1253
#define IMG_CHAR_ASTERISK				1254
#define IMG_CHAR_PLUS					1255
#define IMG_CHAR_COMMA					1256
#define IMG_CHAR_MINUS					1257
#define IMG_CHAR_PERIOD					1258
#define IMG_CHAR_SLASH					1259
#define IMG_CHAR_0					1260
#define IMG_CHAR_1					1261
#define IMG_CHAR_2					1262
#define IMG_CHAR_3					1263
#define IMG_CHAR_4					1264
#define IMG_CHAR_5					1265
#define IMG_CHAR_6					1266
#define IMG_CHAR_7					1267
#define IMG_CHAR_8					1268
#define IMG_CHAR_9					1269
#define IMG_CHAR_COLON					1270
#define IMG_CHAR_SEMICOLON				1271
#define IMG_CHAR_LESS					1272
#define IMG_CHAR_EQUAL					1273
#define IMG_CHAR_GREATER				1274
#define IMG_CHAR_QUESTION				1275
#define IMG_CHAR_AT					1276
#define IMG_CHAR_A					1277
#define IMG_CHAR_B					1278
#define IMG_CHAR_C					1279
#define IMG_CHAR_D					1280
#define IMG_CHAR_E					1281
#define IMG_CHAR_F					1282
#define IMG_CHAR_G					1283
#define IMG_CHAR_H					1284
#define IMG_CHAR_I					1285
#define IMG_CHAR_J					1286
#define IMG_CHAR_K					1287
#define IMG_CHAR_L					1288
#define IMG_CHAR_M					1289
#define IMG_CHAR_N					1290
#define IMG_CHAR_O					1291
#define IMG_CHAR_P					1292
#define IMG_CHAR_Q					1293
#define IMG_CHAR_R					1294
#define IMG_CHAR_S					1295
#define IMG_CHAR_T					1296
#define IMG_CHAR_U					1297
#define IMG_CHAR_V					1298
#define IMG_CHAR_W					1299
#define IMG_CHAR_X					1300
#define IMG_CHAR_Y					1301
#define IMG_CHAR_Z					1302
#define IMG_CHAR_BRACKETLEFT				1303
#define IMG_CHAR_BACKSLASH				1304
#define IMG_CHAR_BRACKETRIGHT				1305
#define IMG_CHAR_ASCIICIRCUM				1306
#define IMG_CHAR_UNDERSCORE				1307
#define IMG_CHAR_COPYRIGHT				1308
#define IMG_CHAR_AUMLAUT				1309
#define IMG_CHAR_OUMLAUT				1310
#define IMG_CHAR_UUMLAUT				1311
#define IMG_CHAR_DEGREE					1312
#define IMG_CHAR_TRADEMARK				1313
#define IMG_CHAR_CURSOR					1314
#define IMG_CHAR_BUTTON					1315
#define IMG_CHAR_UP					1316
#define IMG_CHAR_DOWN					1317
#define IMG_STEEL_CHAR_SPACE				1318
#define IMG_STEEL_CHAR_SPACE_EDITOR			1319
#define IMG_STEEL_CHAR_EXCLAM				1320
#define IMG_STEEL_CHAR_QUOTEDBL				1321
#define IMG_STEEL_CHAR_NUMBERSIGN			1322
#define IMG_STEEL_CHAR_DOLLAR				1323
#define IMG_STEEL_CHAR_PERCENT				1324
#define IMG_STEEL_CHAR_AMPERSAND			1325
#define IMG_STEEL_CHAR_APOSTROPHE			1326
#define IMG_STEEL_CHAR_PARENLEFT			1327
#define IMG_STEEL_CHAR_PARENRIGHT			1328
#define IMG_STEEL_CHAR_ASTERISK				1329
#define IMG_STEEL_CHAR_PLUS				1330
#define IMG_STEEL_CHAR_COMMA				1331
#define IMG_STEEL_CHAR_MINUS				1332
#define IMG_STEEL_CHAR_PERIOD				1333
#define IMG_STEEL_CHAR_SLASH				1334
#define IMG_STEEL_CHAR_0				1335
#define IMG_STEEL_CHAR_1				1336
#define IMG_STEEL_CHAR_2				1337
#define IMG_STEEL_CHAR_3				1338
#define IMG_STEEL_CHAR_4				1339
#define IMG_STEEL_CHAR_5				1340
#define IMG_STEEL_CHAR_6				1341
#define IMG_STEEL_CHAR_7				1342
#define IMG_STEEL_CHAR_8				1343
#define IMG_STEEL_CHAR_9				1344
#define IMG_STEEL_CHAR_COLON				1345
#define IMG_STEEL_CHAR_SEMICOLON			1346
#define IMG_STEEL_CHAR_LESS				1347
#define IMG_STEEL_CHAR_EQUAL				1348
#define IMG_STEEL_CHAR_GREATER				1349
#define IMG_STEEL_CHAR_QUESTION				1350
#define IMG_STEEL_CHAR_AT				1351
#define IMG_STEEL_CHAR_A				1352
#define IMG_STEEL_CHAR_B				1353
#define IMG_STEEL_CHAR_C				1354
#define IMG_STEEL_CHAR_D				1355
#define IMG_STEEL_CHAR_E				1356
#define IMG_STEEL_CHAR_F				1357
#define IMG_STEEL_CHAR_G				1358
#define IMG_STEEL_CHAR_H				1359
#define IMG_STEEL_CHAR_I				1360
#define IMG_STEEL_CHAR_J				1361
#define IMG_STEEL_CHAR_K				1362
#define IMG_STEEL_CHAR_L				1363
#define IMG_STEEL_CHAR_M				1364
#define IMG_STEEL_CHAR_N				1365
#define IMG_STEEL_CHAR_O				1366
#define IMG_STEEL_CHAR_P				1367
#define IMG_STEEL_CHAR_Q				1368
#define IMG_STEEL_CHAR_R				1369
#define IMG_STEEL_CHAR_S				1370
#define IMG_STEEL_CHAR_T				1371
#define IMG_STEEL_CHAR_U				1372
#define IMG_STEEL_CHAR_V				1373
#define IMG_STEEL_CHAR_W				1374
#define IMG_STEEL_CHAR_X				1375
#define IMG_STEEL_CHAR_Y				1376
#define IMG_STEEL_CHAR_Z				1377
#define IMG_STEEL_CHAR_BRACKETLEFT			1378
#define IMG_STEEL_CHAR_BACKSLASH			1379
#define IMG_STEEL_CHAR_BRACKETRIGHT			1380
#define IMG_STEEL_CHAR_ASCIICIRCUM			1381
#define IMG_STEEL_CHAR_UNDERSCORE			1382
#define IMG_STEEL_CHAR_COPYRIGHT			1383
#define IMG_STEEL_CHAR_AUMLAUT				1384
#define IMG_STEEL_CHAR_OUMLAUT				1385
#define IMG_STEEL_CHAR_UUMLAUT				1386
#define IMG_STEEL_CHAR_DEGREE				1387
#define IMG_STEEL_CHAR_TRADEMARK			1388
#define IMG_STEEL_CHAR_CURSOR				1389
#define IMG_STEEL_CHAR_BUTTON				1390
#define IMG_STEEL_CHAR_UP				1391
#define IMG_STEEL_CHAR_DOWN				1392
#define IMG_CUSTOM_1					1393
#define IMG_CUSTOM_1_EDITOR				1394
#define IMG_CUSTOM_2					1395
#define IMG_CUSTOM_2_EDITOR				1396
#define IMG_CUSTOM_3					1397
#define IMG_CUSTOM_3_EDITOR				1398
#define IMG_CUSTOM_4					1399
#define IMG_CUSTOM_4_EDITOR				1400
#define IMG_CUSTOM_5					1401
#define IMG_CUSTOM_5_EDITOR				1402
#define IMG_CUSTOM_6					1403
#define IMG_CUSTOM_6_EDITOR				1404
#define IMG_CUSTOM_7					1405
#define IMG_CUSTOM_7_EDITOR				1406
#define IMG_CUSTOM_8					1407
#define IMG_CUSTOM_8_EDITOR				1408
#define IMG_CUSTOM_9					1409
#define IMG_CUSTOM_9_EDITOR				1410
#define IMG_CUSTOM_10					1411
#define IMG_CUSTOM_10_EDITOR				1412
#define IMG_CUSTOM_11					1413
#define IMG_CUSTOM_11_EDITOR				1414
#define IMG_CUSTOM_12					1415
#define IMG_CUSTOM_12_EDITOR				1416
#define IMG_CUSTOM_13					1417
#define IMG_CUSTOM_13_EDITOR				1418
#define IMG_CUSTOM_14					1419
#define IMG_CUSTOM_14_EDITOR				1420
#define IMG_CUSTOM_15					1421
#define IMG_CUSTOM_15_EDITOR				1422
#define IMG_CUSTOM_16					1423
#define IMG_CUSTOM_16_EDITOR				1424
#define IMG_CUSTOM_17					1425
#define IMG_CUSTOM_17_EDITOR				1426
#define IMG_CUSTOM_18					1427
#define IMG_CUSTOM_18_EDITOR				1428
#define IMG_CUSTOM_19					1429
#define IMG_CUSTOM_19_EDITOR				1430
#define IMG_CUSTOM_20					1431
#define IMG_CUSTOM_20_EDITOR				1432
#define IMG_CUSTOM_21					1433
#define IMG_CUSTOM_21_EDITOR				1434
#define IMG_CUSTOM_22					1435
#define IMG_CUSTOM_22_EDITOR				1436
#define IMG_CUSTOM_23					1437
#define IMG_CUSTOM_23_EDITOR				1438
#define IMG_CUSTOM_24					1439
#define IMG_CUSTOM_24_EDITOR				1440
#define IMG_CUSTOM_25					1441
#define IMG_CUSTOM_25_EDITOR				1442
#define IMG_CUSTOM_26					1443
#define IMG_CUSTOM_26_EDITOR				1444
#define IMG_CUSTOM_27					1445
#define IMG_CUSTOM_27_EDITOR				1446
#define IMG_CUSTOM_28					1447
#define IMG_CUSTOM_28_EDITOR				1448
#define IMG_CUSTOM_29					1449
#define IMG_CUSTOM_29_EDITOR				1450
#define IMG_CUSTOM_30					1451
#define IMG_CUSTOM_30_EDITOR				1452
#define IMG_CUSTOM_31					1453
#define IMG_CUSTOM_31_EDITOR				1454
#define IMG_CUSTOM_32					1455
#define IMG_CUSTOM_32_EDITOR				1456
#define IMG_CUSTOM_33					1457
#define IMG_CUSTOM_33_EDITOR				1458
#define IMG_CUSTOM_34					1459
#define IMG_CUSTOM_34_EDITOR				1460
#define IMG_CUSTOM_35					1461
#define IMG_CUSTOM_35_EDITOR				1462
#define IMG_CUSTOM_36					1463
#define IMG_CUSTOM_36_EDITOR				1464
#define IMG_CUSTOM_37					1465
#define IMG_CUSTOM_37_EDITOR				1466
#define IMG_CUSTOM_38					1467
#define IMG_CUSTOM_38_EDITOR				1468
#define IMG_CUSTOM_39					1469
#define IMG_CUSTOM_39_EDITOR				1470
#define IMG_CUSTOM_40					1471
#define IMG_CUSTOM_40_EDITOR				1472
#define IMG_CUSTOM_41					1473
#define IMG_CUSTOM_41_EDITOR				1474
#define IMG_CUSTOM_42					1475
#define IMG_CUSTOM_42_EDITOR				1476
#define IMG_CUSTOM_43					1477
#define IMG_CUSTOM_43_EDITOR				1478
#define IMG_CUSTOM_44					1479
#define IMG_CUSTOM_44_EDITOR				1480
#define IMG_CUSTOM_45					1481
#define IMG_CUSTOM_45_EDITOR				1482
#define IMG_CUSTOM_46					1483
#define IMG_CUSTOM_46_EDITOR				1484
#define IMG_CUSTOM_47					1485
#define IMG_CUSTOM_47_EDITOR				1486
#define IMG_CUSTOM_48					1487
#define IMG_CUSTOM_48_EDITOR				1488
#define IMG_CUSTOM_49					1489
#define IMG_CUSTOM_49_EDITOR				1490
#define IMG_CUSTOM_50					1491
#define IMG_CUSTOM_50_EDITOR				1492
#define IMG_CUSTOM_51					1493
#define IMG_CUSTOM_51_EDITOR				1494
#define IMG_CUSTOM_52					1495
#define IMG_CUSTOM_52_EDITOR				1496
#define IMG_CUSTOM_53					1497
#define IMG_CUSTOM_53_EDITOR				1498
#define IMG_CUSTOM_54					1499
#define IMG_CUSTOM_54_EDITOR				1500
#define IMG_CUSTOM_55					1501
#define IMG_CUSTOM_55_EDITOR				1502
#define IMG_CUSTOM_56					1503
#define IMG_CUSTOM_56_EDITOR				1504
#define IMG_CUSTOM_57					1505
#define IMG_CUSTOM_57_EDITOR				1506
#define IMG_CUSTOM_58					1507
#define IMG_CUSTOM_58_EDITOR				1508
#define IMG_CUSTOM_59					1509
#define IMG_CUSTOM_59_EDITOR				1510
#define IMG_CUSTOM_60					1511
#define IMG_CUSTOM_60_EDITOR				1512
#define IMG_CUSTOM_61					1513
#define IMG_CUSTOM_61_EDITOR				1514
#define IMG_CUSTOM_62					1515
#define IMG_CUSTOM_62_EDITOR				1516
#define IMG_CUSTOM_63					1517
#define IMG_CUSTOM_63_EDITOR				1518
#define IMG_CUSTOM_64					1519
#define IMG_CUSTOM_64_EDITOR				1520
#define IMG_CUSTOM_65					1521
#define IMG_CUSTOM_65_EDITOR				1522
#define IMG_CUSTOM_66					1523
#define IMG_CUSTOM_66_EDITOR				1524
#define IMG_CUSTOM_67					1525
#define IMG_CUSTOM_67_EDITOR				1526
#define IMG_CUSTOM_68					1527
#define IMG_CUSTOM_68_EDITOR				1528
#define IMG_CUSTOM_69					1529
#define IMG_CUSTOM_69_EDITOR				1530
#define IMG_CUSTOM_70					1531
#define IMG_CUSTOM_70_EDITOR				1532
#define IMG_CUSTOM_71					1533
#define IMG_CUSTOM_71_EDITOR				1534
#define IMG_CUSTOM_72					1535
#define IMG_CUSTOM_72_EDITOR				1536
#define IMG_CUSTOM_73					1537
#define IMG_CUSTOM_73_EDITOR				1538
#define IMG_CUSTOM_74					1539
#define IMG_CUSTOM_74_EDITOR				1540
#define IMG_CUSTOM_75					1541
#define IMG_CUSTOM_75_EDITOR				1542
#define IMG_CUSTOM_76					1543
#define IMG_CUSTOM_76_EDITOR				1544
#define IMG_CUSTOM_77					1545
#define IMG_CUSTOM_77_EDITOR				1546
#define IMG_CUSTOM_78					1547
#define IMG_CUSTOM_78_EDITOR				1548
#define IMG_CUSTOM_79					1549
#define IMG_CUSTOM_79_EDITOR				1550
#define IMG_CUSTOM_80					1551
#define IMG_CUSTOM_80_EDITOR				1552
#define IMG_CUSTOM_81					1553
#define IMG_CUSTOM_81_EDITOR				1554
#define IMG_CUSTOM_82					1555
#define IMG_CUSTOM_82_EDITOR				1556
#define IMG_CUSTOM_83					1557
#define IMG_CUSTOM_83_EDITOR				1558
#define IMG_CUSTOM_84					1559
#define IMG_CUSTOM_84_EDITOR				1560
#define IMG_CUSTOM_85					1561
#define IMG_CUSTOM_85_EDITOR				1562
#define IMG_CUSTOM_86					1563
#define IMG_CUSTOM_86_EDITOR				1564
#define IMG_CUSTOM_87					1565
#define IMG_CUSTOM_87_EDITOR				1566
#define IMG_CUSTOM_88					1567
#define IMG_CUSTOM_88_EDITOR				1568
#define IMG_CUSTOM_89					1569
#define IMG_CUSTOM_89_EDITOR				1570
#define IMG_CUSTOM_90					1571
#define IMG_CUSTOM_90_EDITOR				1572
#define IMG_CUSTOM_91					1573
#define IMG_CUSTOM_91_EDITOR				1574
#define IMG_CUSTOM_92					1575
#define IMG_CUSTOM_92_EDITOR				1576
#define IMG_CUSTOM_93					1577
#define IMG_CUSTOM_93_EDITOR				1578
#define IMG_CUSTOM_94					1579
#define IMG_CUSTOM_94_EDITOR				1580
#define IMG_CUSTOM_95					1581
#define IMG_CUSTOM_95_EDITOR				1582
#define IMG_CUSTOM_96					1583
#define IMG_CUSTOM_96_EDITOR				1584
#define IMG_CUSTOM_97					1585
#define IMG_CUSTOM_97_EDITOR				1586
#define IMG_CUSTOM_98					1587
#define IMG_CUSTOM_98_EDITOR				1588
#define IMG_CUSTOM_99					1589
#define IMG_CUSTOM_99_EDITOR				1590
#define IMG_CUSTOM_100					1591
#define IMG_CUSTOM_100_EDITOR				1592
#define IMG_CUSTOM_101					1593
#define IMG_CUSTOM_101_EDITOR				1594
#define IMG_CUSTOM_102					1595
#define IMG_CUSTOM_102_EDITOR				1596
#define IMG_CUSTOM_103					1597
#define IMG_CUSTOM_103_EDITOR				1598
#define IMG_CUSTOM_104					1599
#define IMG_CUSTOM_104_EDITOR				1600
#define IMG_CUSTOM_105					1601
#define IMG_CUSTOM_105_EDITOR				1602
#define IMG_CUSTOM_106					1603
#define IMG_CUSTOM_106_EDITOR				1604
#define IMG_CUSTOM_107					1605
#define IMG_CUSTOM_107_EDITOR				1606
#define IMG_CUSTOM_108					1607
#define IMG_CUSTOM_108_EDITOR				1608
#define IMG_CUSTOM_109					1609
#define IMG_CUSTOM_109_EDITOR				1610
#define IMG_CUSTOM_110					1611
#define IMG_CUSTOM_110_EDITOR				1612
#define IMG_CUSTOM_111					1613
#define IMG_CUSTOM_111_EDITOR				1614
#define IMG_CUSTOM_112					1615
#define IMG_CUSTOM_112_EDITOR				1616
#define IMG_CUSTOM_113					1617
#define IMG_CUSTOM_113_EDITOR				1618
#define IMG_CUSTOM_114					1619
#define IMG_CUSTOM_114_EDITOR				1620
#define IMG_CUSTOM_115					1621
#define IMG_CUSTOM_115_EDITOR				1622
#define IMG_CUSTOM_116					1623
#define IMG_CUSTOM_116_EDITOR				1624
#define IMG_CUSTOM_117					1625
#define IMG_CUSTOM_117_EDITOR				1626
#define IMG_CUSTOM_118					1627
#define IMG_CUSTOM_118_EDITOR				1628
#define IMG_CUSTOM_119					1629
#define IMG_CUSTOM_119_EDITOR				1630
#define IMG_CUSTOM_120					1631
#define IMG_CUSTOM_120_EDITOR				1632
#define IMG_CUSTOM_121					1633
#define IMG_CUSTOM_121_EDITOR				1634
#define IMG_CUSTOM_122					1635
#define IMG_CUSTOM_122_EDITOR				1636
#define IMG_CUSTOM_123					1637
#define IMG_CUSTOM_123_EDITOR				1638
#define IMG_CUSTOM_124					1639
#define IMG_CUSTOM_124_EDITOR				1640
#define IMG_CUSTOM_125					1641
#define IMG_CUSTOM_125_EDITOR				1642
#define IMG_CUSTOM_126					1643
#define IMG_CUSTOM_126_EDITOR				1644
#define IMG_CUSTOM_127					1645
#define IMG_CUSTOM_127_EDITOR				1646
#define IMG_CUSTOM_128					1647
#define IMG_CUSTOM_128_EDITOR				1648
#define IMG_CUSTOM_129					1649
#define IMG_CUSTOM_129_EDITOR				1650
#define IMG_CUSTOM_130					1651
#define IMG_CUSTOM_130_EDITOR				1652
#define IMG_CUSTOM_131					1653
#define IMG_CUSTOM_131_EDITOR				1654
#define IMG_CUSTOM_132					1655
#define IMG_CUSTOM_132_EDITOR				1656
#define IMG_CUSTOM_133					1657
#define IMG_CUSTOM_133_EDITOR				1658
#define IMG_CUSTOM_134					1659
#define IMG_CUSTOM_134_EDITOR				1660
#define IMG_CUSTOM_135					1661
#define IMG_CUSTOM_135_EDITOR				1662
#define IMG_CUSTOM_136					1663
#define IMG_CUSTOM_136_EDITOR				1664
#define IMG_CUSTOM_137					1665
#define IMG_CUSTOM_137_EDITOR				1666
#define IMG_CUSTOM_138					1667
#define IMG_CUSTOM_138_EDITOR				1668
#define IMG_CUSTOM_139					1669
#define IMG_CUSTOM_139_EDITOR				1670
#define IMG_CUSTOM_140					1671
#define IMG_CUSTOM_140_EDITOR				1672
#define IMG_CUSTOM_141					1673
#define IMG_CUSTOM_141_EDITOR				1674
#define IMG_CUSTOM_142					1675
#define IMG_CUSTOM_142_EDITOR				1676
#define IMG_CUSTOM_143					1677
#define IMG_CUSTOM_143_EDITOR				1678
#define IMG_CUSTOM_144					1679
#define IMG_CUSTOM_144_EDITOR				1680
#define IMG_CUSTOM_145					1681
#define IMG_CUSTOM_145_EDITOR				1682
#define IMG_CUSTOM_146					1683
#define IMG_CUSTOM_146_EDITOR				1684
#define IMG_CUSTOM_147					1685
#define IMG_CUSTOM_147_EDITOR				1686
#define IMG_CUSTOM_148					1687
#define IMG_CUSTOM_148_EDITOR				1688
#define IMG_CUSTOM_149					1689
#define IMG_CUSTOM_149_EDITOR				1690
#define IMG_CUSTOM_150					1691
#define IMG_CUSTOM_150_EDITOR				1692
#define IMG_CUSTOM_151					1693
#define IMG_CUSTOM_151_EDITOR				1694
#define IMG_CUSTOM_152					1695
#define IMG_CUSTOM_152_EDITOR				1696
#define IMG_CUSTOM_153					1697
#define IMG_CUSTOM_153_EDITOR				1698
#define IMG_CUSTOM_154					1699
#define IMG_CUSTOM_154_EDITOR				1700
#define IMG_CUSTOM_155					1701
#define IMG_CUSTOM_155_EDITOR				1702
#define IMG_CUSTOM_156					1703
#define IMG_CUSTOM_156_EDITOR				1704
#define IMG_CUSTOM_157					1705
#define IMG_CUSTOM_157_EDITOR				1706
#define IMG_CUSTOM_158					1707
#define IMG_CUSTOM_158_EDITOR				1708
#define IMG_CUSTOM_159					1709
#define IMG_CUSTOM_159_EDITOR				1710
#define IMG_CUSTOM_160					1711
#define IMG_CUSTOM_160_EDITOR				1712
#define IMG_CUSTOM_161					1713
#define IMG_CUSTOM_161_EDITOR				1714
#define IMG_CUSTOM_162					1715
#define IMG_CUSTOM_162_EDITOR				1716
#define IMG_CUSTOM_163					1717
#define IMG_CUSTOM_163_EDITOR				1718
#define IMG_CUSTOM_164					1719
#define IMG_CUSTOM_164_EDITOR				1720
#define IMG_CUSTOM_165					1721
#define IMG_CUSTOM_165_EDITOR				1722
#define IMG_CUSTOM_166					1723
#define IMG_CUSTOM_166_EDITOR				1724
#define IMG_CUSTOM_167					1725
#define IMG_CUSTOM_167_EDITOR				1726
#define IMG_CUSTOM_168					1727
#define IMG_CUSTOM_168_EDITOR				1728
#define IMG_CUSTOM_169					1729
#define IMG_CUSTOM_169_EDITOR				1730
#define IMG_CUSTOM_170					1731
#define IMG_CUSTOM_170_EDITOR				1732
#define IMG_CUSTOM_171					1733
#define IMG_CUSTOM_171_EDITOR				1734
#define IMG_CUSTOM_172					1735
#define IMG_CUSTOM_172_EDITOR				1736
#define IMG_CUSTOM_173					1737
#define IMG_CUSTOM_173_EDITOR				1738
#define IMG_CUSTOM_174					1739
#define IMG_CUSTOM_174_EDITOR				1740
#define IMG_CUSTOM_175					1741
#define IMG_CUSTOM_175_EDITOR				1742
#define IMG_CUSTOM_176					1743
#define IMG_CUSTOM_176_EDITOR				1744
#define IMG_CUSTOM_177					1745
#define IMG_CUSTOM_177_EDITOR				1746
#define IMG_CUSTOM_178					1747
#define IMG_CUSTOM_178_EDITOR				1748
#define IMG_CUSTOM_179					1749
#define IMG_CUSTOM_179_EDITOR				1750
#define IMG_CUSTOM_180					1751
#define IMG_CUSTOM_180_EDITOR				1752
#define IMG_CUSTOM_181					1753
#define IMG_CUSTOM_181_EDITOR				1754
#define IMG_CUSTOM_182					1755
#define IMG_CUSTOM_182_EDITOR				1756
#define IMG_CUSTOM_183					1757
#define IMG_CUSTOM_183_EDITOR				1758
#define IMG_CUSTOM_184					1759
#define IMG_CUSTOM_184_EDITOR				1760
#define IMG_CUSTOM_185					1761
#define IMG_CUSTOM_185_EDITOR				1762
#define IMG_CUSTOM_186					1763
#define IMG_CUSTOM_186_EDITOR				1764
#define IMG_CUSTOM_187					1765
#define IMG_CUSTOM_187_EDITOR				1766
#define IMG_CUSTOM_188					1767
#define IMG_CUSTOM_188_EDITOR				1768
#define IMG_CUSTOM_189					1769
#define IMG_CUSTOM_189_EDITOR				1770
#define IMG_CUSTOM_190					1771
#define IMG_CUSTOM_190_EDITOR				1772
#define IMG_CUSTOM_191					1773
#define IMG_CUSTOM_191_EDITOR				1774
#define IMG_CUSTOM_192					1775
#define IMG_CUSTOM_192_EDITOR				1776
#define IMG_CUSTOM_193					1777
#define IMG_CUSTOM_193_EDITOR				1778
#define IMG_CUSTOM_194					1779
#define IMG_CUSTOM_194_EDITOR				1780
#define IMG_CUSTOM_195					1781
#define IMG_CUSTOM_195_EDITOR				1782
#define IMG_CUSTOM_196					1783
#define IMG_CUSTOM_196_EDITOR				1784
#define IMG_CUSTOM_197					1785
#define IMG_CUSTOM_197_EDITOR				1786
#define IMG_CUSTOM_198					1787
#define IMG_CUSTOM_198_EDITOR				1788
#define IMG_CUSTOM_199					1789
#define IMG_CUSTOM_199_EDITOR				1790
#define IMG_CUSTOM_200					1791
#define IMG_CUSTOM_200_EDITOR				1792
#define IMG_CUSTOM_201					1793
#define IMG_CUSTOM_201_EDITOR				1794
#define IMG_CUSTOM_202					1795
#define IMG_CUSTOM_202_EDITOR				1796
#define IMG_CUSTOM_203					1797
#define IMG_CUSTOM_203_EDITOR				1798
#define IMG_CUSTOM_204					1799
#define IMG_CUSTOM_204_EDITOR				1800
#define IMG_CUSTOM_205					1801
#define IMG_CUSTOM_205_EDITOR				1802
#define IMG_CUSTOM_206					1803
#define IMG_CUSTOM_206_EDITOR				1804
#define IMG_CUSTOM_207					1805
#define IMG_CUSTOM_207_EDITOR				1806
#define IMG_CUSTOM_208					1807
#define IMG_CUSTOM_208_EDITOR				1808
#define IMG_CUSTOM_209					1809
#define IMG_CUSTOM_209_EDITOR				1810
#define IMG_CUSTOM_210					1811
#define IMG_CUSTOM_210_EDITOR				1812
#define IMG_CUSTOM_211					1813
#define IMG_CUSTOM_211_EDITOR				1814
#define IMG_CUSTOM_212					1815
#define IMG_CUSTOM_212_EDITOR				1816
#define IMG_CUSTOM_213					1817
#define IMG_CUSTOM_213_EDITOR				1818
#define IMG_CUSTOM_214					1819
#define IMG_CUSTOM_214_EDITOR				1820
#define IMG_CUSTOM_215					1821
#define IMG_CUSTOM_215_EDITOR				1822
#define IMG_CUSTOM_216					1823
#define IMG_CUSTOM_216_EDITOR				1824
#define IMG_CUSTOM_217					1825
#define IMG_CUSTOM_217_EDITOR				1826
#define IMG_CUSTOM_218					1827
#define IMG_CUSTOM_218_EDITOR				1828
#define IMG_CUSTOM_219					1829
#define IMG_CUSTOM_219_EDITOR				1830
#define IMG_CUSTOM_220					1831
#define IMG_CUSTOM_220_EDITOR				1832
#define IMG_CUSTOM_221					1833
#define IMG_CUSTOM_221_EDITOR				1834
#define IMG_CUSTOM_222					1835
#define IMG_CUSTOM_222_EDITOR				1836
#define IMG_CUSTOM_223					1837
#define IMG_CUSTOM_223_EDITOR				1838
#define IMG_CUSTOM_224					1839
#define IMG_CUSTOM_224_EDITOR				1840
#define IMG_CUSTOM_225					1841
#define IMG_CUSTOM_225_EDITOR				1842
#define IMG_CUSTOM_226					1843
#define IMG_CUSTOM_226_EDITOR				1844
#define IMG_CUSTOM_227					1845
#define IMG_CUSTOM_227_EDITOR				1846
#define IMG_CUSTOM_228					1847
#define IMG_CUSTOM_228_EDITOR				1848
#define IMG_CUSTOM_229					1849
#define IMG_CUSTOM_229_EDITOR				1850
#define IMG_CUSTOM_230					1851
#define IMG_CUSTOM_230_EDITOR				1852
#define IMG_CUSTOM_231					1853
#define IMG_CUSTOM_231_EDITOR				1854
#define IMG_CUSTOM_232					1855
#define IMG_CUSTOM_232_EDITOR				1856
#define IMG_CUSTOM_233					1857
#define IMG_CUSTOM_233_EDITOR				1858
#define IMG_CUSTOM_234					1859
#define IMG_CUSTOM_234_EDITOR				1860
#define IMG_CUSTOM_235					1861
#define IMG_CUSTOM_235_EDITOR				1862
#define IMG_CUSTOM_236					1863
#define IMG_CUSTOM_236_EDITOR				1864
#define IMG_CUSTOM_237					1865
#define IMG_CUSTOM_237_EDITOR				1866
#define IMG_CUSTOM_238					1867
#define IMG_CUSTOM_238_EDITOR				1868
#define IMG_CUSTOM_239					1869
#define IMG_CUSTOM_239_EDITOR				1870
#define IMG_CUSTOM_240					1871
#define IMG_CUSTOM_240_EDITOR				1872
#define IMG_CUSTOM_241					1873
#define IMG_CUSTOM_241_EDITOR				1874
#define IMG_CUSTOM_242					1875
#define IMG_CUSTOM_242_EDITOR				1876
#define IMG_CUSTOM_243					1877
#define IMG_CUSTOM_243_EDITOR				1878
#define IMG_CUSTOM_244					1879
#define IMG_CUSTOM_244_EDITOR				1880
#define IMG_CUSTOM_245					1881
#define IMG_CUSTOM_245_EDITOR				1882
#define IMG_CUSTOM_246					1883
#define IMG_CUSTOM_246_EDITOR				1884
#define IMG_CUSTOM_247					1885
#define IMG_CUSTOM_247_EDITOR				1886
#define IMG_CUSTOM_248					1887
#define IMG_CUSTOM_248_EDITOR				1888
#define IMG_CUSTOM_249					1889
#define IMG_CUSTOM_249_EDITOR				1890
#define IMG_CUSTOM_250					1891
#define IMG_CUSTOM_250_EDITOR				1892
#define IMG_CUSTOM_251					1893
#define IMG_CUSTOM_251_EDITOR				1894
#define IMG_CUSTOM_252					1895
#define IMG_CUSTOM_252_EDITOR				1896
#define IMG_CUSTOM_253					1897
#define IMG_CUSTOM_253_EDITOR				1898
#define IMG_CUSTOM_254					1899
#define IMG_CUSTOM_254_EDITOR				1900
#define IMG_CUSTOM_255					1901
#define IMG_CUSTOM_255_EDITOR				1902
#define IMG_CUSTOM_256					1903
#define IMG_CUSTOM_256_EDITOR				1904
#define IMG_GROUP_1					1905
#define IMG_GROUP_1_EDITOR				1906
#define IMG_GROUP_2					1907
#define IMG_GROUP_2_EDITOR				1908
#define IMG_GROUP_3					1909
#define IMG_GROUP_3_EDITOR				1910
#define IMG_GROUP_4					1911
#define IMG_GROUP_4_EDITOR				1912
#define IMG_GROUP_5					1913
#define IMG_GROUP_5_EDITOR				1914
#define IMG_GROUP_6					1915
#define IMG_GROUP_6_EDITOR				1916
#define IMG_GROUP_7					1917
#define IMG_GROUP_7_EDITOR				1918
#define IMG_GROUP_8					1919
#define IMG_GROUP_8_EDITOR				1920
#define IMG_GROUP_9					1921
#define IMG_GROUP_9_EDITOR				1922
#define IMG_GROUP_10					1923
#define IMG_GROUP_10_EDITOR				1924
#define IMG_GROUP_11					1925
#define IMG_GROUP_11_EDITOR				1926
#define IMG_GROUP_12					1927
#define IMG_GROUP_12_EDITOR				1928
#define IMG_GROUP_13					1929
#define IMG_GROUP_13_EDITOR				1930
#define IMG_GROUP_14					1931
#define IMG_GROUP_14_EDITOR				1932
#define IMG_GROUP_15					1933
#define IMG_GROUP_15_EDITOR				1934
#define IMG_GROUP_16					1935
#define IMG_GROUP_16_EDITOR				1936
#define IMG_GROUP_17					1937
#define IMG_GROUP_17_EDITOR				1938
#define IMG_GROUP_18					1939
#define IMG_GROUP_18_EDITOR				1940
#define IMG_GROUP_19					1941
#define IMG_GROUP_19_EDITOR				1942
#define IMG_GROUP_20					1943
#define IMG_GROUP_20_EDITOR				1944
#define IMG_GROUP_21					1945
#define IMG_GROUP_21_EDITOR				1946
#define IMG_GROUP_22					1947
#define IMG_GROUP_22_EDITOR				1948
#define IMG_GROUP_23					1949
#define IMG_GROUP_23_EDITOR				1950
#define IMG_GROUP_24					1951
#define IMG_GROUP_24_EDITOR				1952
#define IMG_GROUP_25					1953
#define IMG_GROUP_25_EDITOR				1954
#define IMG_GROUP_26					1955
#define IMG_GROUP_26_EDITOR				1956
#define IMG_GROUP_27					1957
#define IMG_GROUP_27_EDITOR				1958
#define IMG_GROUP_28					1959
#define IMG_GROUP_28_EDITOR				1960
#define IMG_GROUP_29					1961
#define IMG_GROUP_29_EDITOR				1962
#define IMG_GROUP_30					1963
#define IMG_GROUP_30_EDITOR				1964
#define IMG_GROUP_31					1965
#define IMG_GROUP_31_EDITOR				1966
#define IMG_GROUP_32					1967
#define IMG_GROUP_32_EDITOR				1968
#define IMG_EMPTY_SPACE_1				1969
#define IMG_EMPTY_SPACE_1_EDITOR			1970
#define IMG_EMPTY_SPACE_2				1971
#define IMG_EMPTY_SPACE_2_EDITOR			1972
#define IMG_EMPTY_SPACE_3				1973
#define IMG_EMPTY_SPACE_3_EDITOR			1974
#define IMG_EMPTY_SPACE_4				1975
#define IMG_EMPTY_SPACE_4_EDITOR			1976
#define IMG_EMPTY_SPACE_5				1977
#define IMG_EMPTY_SPACE_5_EDITOR			1978
#define IMG_EMPTY_SPACE_6				1979
#define IMG_EMPTY_SPACE_6_EDITOR			1980
#define IMG_EMPTY_SPACE_7				1981
#define IMG_EMPTY_SPACE_7_EDITOR			1982
#define IMG_EMPTY_SPACE_8				1983
#define IMG_EMPTY_SPACE_8_EDITOR			1984
#define IMG_EMPTY_SPACE_9				1985
#define IMG_EMPTY_SPACE_9_EDITOR			1986
#define IMG_EMPTY_SPACE_10				1987
#define IMG_EMPTY_SPACE_10_EDITOR			1988
#define IMG_EMPTY_SPACE_11				1989
#define IMG_EMPTY_SPACE_11_EDITOR			1990
#define IMG_EMPTY_SPACE_12				1991
#define IMG_EMPTY_SPACE_12_EDITOR			1992
#define IMG_EMPTY_SPACE_13				1993
#define IMG_EMPTY_SPACE_13_EDITOR			1994
#define IMG_EMPTY_SPACE_14				1995
#define IMG_EMPTY_SPACE_14_EDITOR			1996
#define IMG_EMPTY_SPACE_15				1997
#define IMG_EMPTY_SPACE_15_EDITOR			1998
#define IMG_EMPTY_SPACE_16				1999
#define IMG_EMPTY_SPACE_16_EDITOR			2000
#define IMG_SP_FRAME_HORIZONTAL				2001
#define IMG_SP_FRAME_VERTICAL				2002
#define IMG_SP_FRAME_CORNER				2003
#define IMG_TOON_1					2004
#define IMG_TOON_2					2005
#define IMG_TOON_3					2006
#define IMG_TOON_4					2007
#define IMG_TOON_5					2008
#define IMG_TOON_6					2009
#define IMG_TOON_7					2010
#define IMG_TOON_8					2011
#define IMG_TOON_9					2012
#define IMG_TOON_10					2013
#define IMG_TOON_11					2014
#define IMG_TOON_12					2015
#define IMG_TOON_13					2016
#define IMG_TOON_14					2017
#define IMG_TOON_15					2018
#define IMG_TOON_16					2019
#define IMG_TOON_17					2020
#define IMG_TOON_18					2021
#define IMG_TOON_19					2022
#define IMG_TOON_20					2023
#define IMG_GFX_GLOBAL_ANIM_1				2024
#define IMG_GFX_GLOBAL_ANIM_2				2025
#define IMG_GFX_GLOBAL_ANIM_3				2026
#define IMG_GFX_GLOBAL_ANIM_4				2027
#define IMG_GFX_GLOBAL_ANIM_5				2028
#define IMG_GFX_GLOBAL_ANIM_6				2029
#define IMG_GFX_GLOBAL_ANIM_7				2030
#define IMG_GFX_GLOBAL_ANIM_8				2031
#define IMG_GFX_GLOBAL_ANIM_9				2032
#define IMG_GFX_GLOBAL_ANIM_10				2033
#define IMG_GFX_GLOBAL_ANIM_11				2034
#define IMG_GFX_GLOBAL_ANIM_12				2035
#define IMG_GFX_GLOBAL_ANIM_13				2036
#define IMG_GFX_GLOBAL_ANIM_14				2037
#define IMG_GFX_GLOBAL_ANIM_15				2038
#define IMG_GFX_GLOBAL_ANIM_16				2039
#define IMG_GFX_GLOBAL_ANIM_17				2040
#define IMG_GFX_GLOBAL_ANIM_18				2041
#define IMG_GFX_GLOBAL_ANIM_19				2042
#define IMG_GFX_GLOBAL_ANIM_20				2043
#define IMG_GFX_GLOBAL_ANIM_21				2044
#define IMG_GFX_GLOBAL_ANIM_22				2045
#define IMG_GFX_GLOBAL_ANIM_23				2046
#define IMG_GFX_GLOBAL_ANIM_24				2047
#define IMG_GFX_GLOBAL_ANIM_25				2048
#define IMG_GFX_GLOBAL_ANIM_26				2049
#define IMG_GFX_GLOBAL_ANIM_27				2050
#define IMG_GFX_GLOBAL_ANIM_28				2051
#define IMG_GFX_GLOBAL_ANIM_29				2052
#define IMG_GFX_GLOBAL_ANIM_30				2053
#define IMG_GFX_GLOBAL_ANIM_31				2054
#define IMG_GFX_GLOBAL_ANIM_32				2055
#define IMG_GLOBAL_ANIM_1				2056
#define IMG_GLOBAL_ANIM_2				2057
#define IMG_GLOBAL_ANIM_3				2058
#define IMG_GLOBAL_ANIM_4				2059
#define IMG_GLOBAL_ANIM_5				2060
#define IMG_GLOBAL_ANIM_6				2061
#define IMG_GLOBAL_ANIM_7				2062
#define IMG_GLOBAL_ANIM_8				2063
#define IMG_GLOBAL_ANIM_9				2064
#define IMG_GLOBAL_ANIM_10				2065
#define IMG_GLOBAL_ANIM_11				2066
#define IMG_GLOBAL_ANIM_12				2067
#define IMG_GLOBAL_ANIM_13				2068
#define IMG_GLOBAL_ANIM_14				2069
#define IMG_GLOBAL_ANIM_15				2070
#define IMG_GLOBAL_ANIM_16				2071
#define IMG_GLOBAL_ANIM_17				2072
#define IMG_GLOBAL_ANIM_18				2073
#define IMG_GLOBAL_ANIM_19				2074
#define IMG_GLOBAL_ANIM_20				2075
#define IMG_GLOBAL_ANIM_21				2076
#define IMG_GLOBAL_ANIM_22				2077
#define IMG_GLOBAL_ANIM_23				2078
#define IMG_GLOBAL_ANIM_24				2079
#define IMG_GLOBAL_ANIM_25				2080
#define IMG_GLOBAL_ANIM_26				2081
#define IMG_GLOBAL_ANIM_27				2082
#define IMG_GLOBAL_ANIM_28				2083
#define IMG_GLOBAL_ANIM_29				2084
#define IMG_GLOBAL_ANIM_30				2085
#define IMG_GLOBAL_ANIM_31				2086
#define IMG_GLOBAL_ANIM_32				2087
#define IMG_INTERNAL_GLOBAL_TOON_DEFAULT		2088
#define IMG_INTERNAL_GLOBAL_ANIM_DEFAULT		2089
#define IMG_MENU_CALIBRATE_RED				2090
#define IMG_MENU_CALIBRATE_BLUE				2091
#define IMG_MENU_CALIBRATE_YELLOW			2092
#define IMG_MENU_BUTTON					2093
#define IMG_MENU_BUTTON_ACTIVE				2094
#define IMG_MENU_BUTTON_LEFT				2095
#define IMG_MENU_BUTTON_LEFT_ACTIVE			2096
#define IMG_MENU_BUTTON_RIGHT				2097
#define IMG_MENU_BUTTON_RIGHT_ACTIVE			2098
#define IMG_MENU_BUTTON_UP				2099
#define IMG_MENU_BUTTON_UP_ACTIVE			2100
#define IMG_MENU_BUTTON_DOWN				2101
#define IMG_MENU_BUTTON_DOWN_ACTIVE			2102
#define IMG_MENU_BUTTON_ENTER_MENU			2103
#define IMG_MENU_BUTTON_ENTER_MENU_ACTIVE		2104
#define IMG_MENU_BUTTON_LEAVE_MENU			2105
#define IMG_MENU_BUTTON_LEAVE_MENU_ACTIVE		2106
#define IMG_MENU_BUTTON_NEXT_LEVEL			2107
#define IMG_MENU_BUTTON_NEXT_LEVEL_ACTIVE		2108
#define IMG_MENU_BUTTON_PREV_LEVEL			2109
#define IMG_MENU_BUTTON_PREV_LEVEL_ACTIVE		2110
#define IMG_MENU_BUTTON_NEXT_LEVEL2			2111
#define IMG_MENU_BUTTON_NEXT_LEVEL2_ACTIVE		2112
#define IMG_MENU_BUTTON_PREV_LEVEL2			2113
#define IMG_MENU_BUTTON_PREV_LEVEL2_ACTIVE		2114
#define IMG_MENU_BUTTON_NEXT_SCORE			2115
#define IMG_MENU_BUTTON_NEXT_SCORE_ACTIVE		2116
#define IMG_MENU_BUTTON_PREV_SCORE			2117
#define IMG_MENU_BUTTON_PREV_SCORE_ACTIVE		2118
#define IMG_MENU_BUTTON_PLAY_TAPE			2119
#define IMG_MENU_BUTTON_NAME				2120
#define IMG_MENU_BUTTON_NAME_ACTIVE			2121
#define IMG_MENU_BUTTON_LEVELS				2122
#define IMG_MENU_BUTTON_LEVELS_ACTIVE			2123
#define IMG_MENU_BUTTON_SCORES				2124
#define IMG_MENU_BUTTON_SCORES_ACTIVE			2125
#define IMG_MENU_BUTTON_EDITOR				2126
#define IMG_MENU_BUTTON_EDITOR_ACTIVE			2127
#define IMG_MENU_BUTTON_INFO				2128
#define IMG_MENU_BUTTON_INFO_ACTIVE			2129
#define IMG_MENU_BUTTON_GAME				2130
#define IMG_MENU_BUTTON_GAME_ACTIVE			2131
#define IMG_MENU_BUTTON_SETUP				2132
#define IMG_MENU_BUTTON_SETUP_ACTIVE			2133
#define IMG_MENU_BUTTON_QUIT				2134
#define IMG_MENU_BUTTON_QUIT_ACTIVE			2135
#define IMG_MENU_BUTTON_FIRST_LEVEL			2136
#define IMG_MENU_BUTTON_FIRST_LEVEL_ACTIVE		2137
#define IMG_MENU_BUTTON_LAST_LEVEL			2138
#define IMG_MENU_BUTTON_LAST_LEVEL_ACTIVE		2139
#define IMG_MENU_BUTTON_LEVEL_NUMBER			2140
#define IMG_MENU_BUTTON_LEVEL_NUMBER_ACTIVE		2141
#define IMG_MENU_BUTTON_INSERT_SOLUTION			2142
#define IMG_MENU_BUTTON_INSERT_SOLUTION_ACTIVE		2143
#define IMG_MENU_BUTTON_PLAY_SOLUTION			2144
#define IMG_MENU_BUTTON_PLAY_SOLUTION_ACTIVE		2145
#define IMG_MENU_BUTTON_LEVELSET_INFO			2146
#define IMG_MENU_BUTTON_LEVELSET_INFO_PRESSED		2147
#define IMG_MENU_BUTTON_LEVELSET_INFO_ACTIVE		2148
#define IMG_MENU_BUTTON_SWITCH_ECS_AGA			2149
#define IMG_MENU_BUTTON_SWITCH_ECS_AGA_ACTIVE		2150
#define IMG_MENU_BUTTON_TOUCH_BACK			2151
#define IMG_MENU_BUTTON_TOUCH_NEXT			2152
#define IMG_MENU_BUTTON_TOUCH_BACK2			2153
#define IMG_MENU_BUTTON_TOUCH_NEXT2			2154
#define IMG_MENU_SCROLLBAR				2155
#define IMG_MENU_SCROLLBAR_ACTIVE			2156
#define IMG_GFX_GAME_PANEL_TIME_ANIM			2157
#define IMG_GFX_GAME_PANEL_TIME_ANIM_ACTIVE		2158
#define IMG_GFX_GAME_PANEL_HEALTH_ANIM			2159
#define IMG_GFX_GAME_PANEL_HEALTH_ANIM_ACTIVE		2160
#define IMG_GFX_GAME_BUTTON_STOP			2161
#define IMG_GFX_GAME_BUTTON_PAUSE			2162
#define IMG_GFX_GAME_BUTTON_PLAY			2163
#define IMG_GFX_GAME_BUTTON_UNDO			2164
#define IMG_GFX_GAME_BUTTON_REDO			2165
#define IMG_GFX_GAME_BUTTON_SAVE			2166
#define IMG_GFX_GAME_BUTTON_PAUSE2			2167
#define IMG_GFX_GAME_BUTTON_LOAD			2168
#define IMG_GFX_GAME_BUTTON_SOUND_MUSIC			2169
#define IMG_GFX_GAME_BUTTON_SOUND_LOOPS			2170
#define IMG_GFX_GAME_BUTTON_SOUND_SIMPLE		2171
#define IMG_GFX_GAME_BUTTON_PANEL_STOP			2172
#define IMG_GFX_GAME_BUTTON_PANEL_PAUSE			2173
#define IMG_GFX_GAME_BUTTON_PANEL_PLAY			2174
#define IMG_GFX_GAME_BUTTON_PANEL_SOUND_MUSIC		2175
#define IMG_GFX_GAME_BUTTON_PANEL_SOUND_LOOPS		2176
#define IMG_GFX_GAME_BUTTON_PANEL_SOUND_SIMPLE		2177
#define IMG_GFX_GAME_BUTTON_TOUCH_STOP			2178
#define IMG_GFX_GAME_BUTTON_TOUCH_PAUSE			2179
#define IMG_GFX_TAPE_BUTTON_EJECT			2180
#define IMG_GFX_TAPE_BUTTON_EXTRA			2181
#define IMG_GFX_TAPE_BUTTON_STOP			2182
#define IMG_GFX_TAPE_BUTTON_PAUSE			2183
#define IMG_GFX_TAPE_BUTTON_RECORD			2184
#define IMG_GFX_TAPE_BUTTON_PLAY			2185
#define IMG_GFX_TAPE_BUTTON_INSERT_SOLUTION		2186
#define IMG_GFX_TAPE_BUTTON_PLAY_SOLUTION		2187
#define IMG_GFX_TAPE_SYMBOL_EJECT			2188
#define IMG_GFX_TAPE_SYMBOL_STOP			2189
#define IMG_GFX_TAPE_SYMBOL_PAUSE			2190
#define IMG_GFX_TAPE_SYMBOL_RECORD			2191
#define IMG_GFX_TAPE_SYMBOL_PLAY			2192
#define IMG_GFX_TAPE_SYMBOL_FAST_FORWARD		2193
#define IMG_GFX_TAPE_SYMBOL_WARP_FORWARD		2194
#define IMG_GFX_TAPE_SYMBOL_WARP_FORWARD_BLIND		2195
#define IMG_GFX_TAPE_SYMBOL_PAUSE_BEFORE_END		2196
#define IMG_GFX_TAPE_SYMBOL_SINGLE_STEP			2197
#define IMG_GFX_TAPE_LABEL_EJECT			2198
#define IMG_GFX_TAPE_LABEL_STOP				2199
#define IMG_GFX_TAPE_LABEL_PAUSE			2200
#define IMG_GFX_TAPE_LABEL_RECORD			2201
#define IMG_GFX_TAPE_LABEL_PLAY				2202
#define IMG_GFX_TAPE_LABEL_FAST_FORWARD			2203
#define IMG_GFX_TAPE_LABEL_WARP_FORWARD			2204
#define IMG_GFX_TAPE_LABEL_WARP_FORWARD_BLIND		2205
#define IMG_GFX_TAPE_LABEL_PAUSE_BEFORE_END		2206
#define IMG_GFX_TAPE_LABEL_SINGLE_STEP			2207
#define IMG_GFX_TAPE_LABEL_DATE				2208
#define IMG_GFX_TAPE_LABEL_TIME				2209
#define IMG_GFX_REQUEST_BUTTON_YES			2210
#define IMG_GFX_REQUEST_BUTTON_NO			2211
#define IMG_GFX_REQUEST_BUTTON_CONFIRM			2212
#define IMG_GFX_REQUEST_BUTTON_PLAYER_1			2213
#define IMG_GFX_REQUEST_BUTTON_PLAYER_2			2214
#define IMG_GFX_REQUEST_BUTTON_PLAYER_3			2215
#define IMG_GFX_REQUEST_BUTTON_PLAYER_4			2216
#define IMG_GFX_REQUEST_BUTTON_TOUCH_YES		2217
#define IMG_GFX_REQUEST_BUTTON_TOUCH_NO			2218
#define IMG_GFX_REQUEST_BUTTON_TOUCH_CONFIRM		2219
#define IMG_FONT_INITIAL_1				2220
#define IMG_FONT_INITIAL_2				2221
#define IMG_FONT_INITIAL_3				2222
#define IMG_FONT_INITIAL_4				2223
#define IMG_FONT_TITLE_1				2224
#define IMG_FONT_TITLE_2				2225
#define IMG_FONT_TITLE_2_SETUP				2226
#define IMG_FONT_MENU_1					2227
#define IMG_FONT_MENU_1_ACTIVE				2228
#define IMG_FONT_MENU_2					2229
#define IMG_FONT_MENU_2_ACTIVE				2230
#define IMG_FONT_TEXT_1					2231
#define IMG_FONT_TEXT_1_MAIN				2232
#define IMG_FONT_TEXT_1_LEVELS				2233
#define IMG_FONT_TEXT_1_LEVELNR				2234
#define IMG_FONT_TEXT_1_SETUP				2235
#define IMG_FONT_TEXT_1_NAMES				2236
#define IMG_FONT_TEXT_1_PREVIEW				2237
#define IMG_FONT_TEXT_1_SCORES				2238
#define IMG_FONT_TEXT_1_ACTIVE_SCORES			2239
#define IMG_FONT_TEXT_1_PANEL				2240
#define IMG_FONT_TEXT_1_DOOR				2241
#define IMG_FONT_TEXT_2					2242
#define IMG_FONT_TEXT_2_MAIN				2243
#define IMG_FONT_TEXT_2_LEVELS				2244
#define IMG_FONT_TEXT_2_LEVELNR				2245
#define IMG_FONT_TEXT_2_SETUP				2246
#define IMG_FONT_TEXT_2_NAMES				2247
#define IMG_FONT_TEXT_2_PREVIEW				2248
#define IMG_FONT_TEXT_2_SCORES				2249
#define IMG_FONT_TEXT_2_ACTIVE_SCORES			2250
#define IMG_FONT_TEXT_3					2251
#define IMG_FONT_TEXT_3_LEVELS				2252
#define IMG_FONT_TEXT_3_LEVELNR				2253
#define IMG_FONT_TEXT_3_SETUP				2254
#define IMG_FONT_TEXT_3_NAMES				2255
#define IMG_FONT_TEXT_3_PREVIEW				2256
#define IMG_FONT_TEXT_3_SCORES				2257
#define IMG_FONT_TEXT_3_ACTIVE_SCORES			2258
#define IMG_FONT_TEXT_4					2259
#define IMG_FONT_TEXT_4_MAIN				2260
#define IMG_FONT_TEXT_4_LEVELS				2261
#define IMG_FONT_TEXT_4_LEVELNR				2262
#define IMG_FONT_TEXT_4_SETUP				2263
#define IMG_FONT_TEXT_4_NAMES				2264
#define IMG_FONT_TEXT_4_SCORES				2265
#define IMG_FONT_TEXT_4_ACTIVE_SCORES			2266
#define IMG_FONT_ENVELOPE_1				2267
#define IMG_FONT_ENVELOPE_2				2268
#define IMG_FONT_ENVELOPE_3				2269
#define IMG_FONT_ENVELOPE_4				2270
#define IMG_FONT_REQUEST				2271
#define IMG_FONT_INPUT_1				2272
#define IMG_FONT_INPUT_1_MAIN				2273
#define IMG_FONT_INPUT_1_NAMES				2274
#define IMG_FONT_INPUT_1_ACTIVE				2275
#define IMG_FONT_INPUT_1_ACTIVE_MAIN			2276
#define IMG_FONT_INPUT_1_ACTIVE_NAMES			2277
#define IMG_FONT_INPUT_1_ACTIVE_SETUP			2278
#define IMG_FONT_INPUT_2				2279
#define IMG_FONT_INPUT_2_ACTIVE				2280
#define IMG_FONT_OPTION_OFF				2281
#define IMG_FONT_OPTION_OFF_NARROW			2282
#define IMG_FONT_OPTION_ON				2283
#define IMG_FONT_OPTION_ON_NARROW			2284
#define IMG_FONT_VALUE_1				2285
#define IMG_FONT_VALUE_2				2286
#define IMG_FONT_VALUE_OLD				2287
#define IMG_FONT_VALUE_OLD_NARROW			2288
#define IMG_FONT_VALUE_NARROW				2289
#define IMG_FONT_LEVEL_NUMBER				2290
#define IMG_FONT_LEVEL_NUMBER_ACTIVE			2291
#define IMG_FONT_TAPE_RECORDER				2292
#define IMG_FONT_GAME_INFO				2293
#define IMG_FONT_INFO_ELEMENTS				2294
#define IMG_FONT_INFO_LEVELSET				2295
#define IMG_FONT_MAIN_NETWORK_PLAYERS			2296
#define IMG_EDITOR_ELEMENT_BORDER			2297
#define IMG_EDITOR_ELEMENT_BORDER_INPUT			2298
#define IMG_EDITOR_COUNTER_DOWN				2299
#define IMG_EDITOR_COUNTER_UP				2300
#define IMG_EDITOR_COUNTER_INPUT			2301
#define IMG_EDITOR_SELECTBOX_INPUT			2302
#define IMG_EDITOR_SELECTBOX_BUTTON			2303
#define IMG_EDITOR_CHECKBOX				2304
#define IMG_EDITOR_RADIOBUTTON				2305
#define IMG_EDITOR_STICKYBUTTON				2306
#define IMG_EDITOR_TABBUTTON				2307
#define IMG_EDITOR_TEXTBUTTON				2308
#define IMG_EDITOR_INPUT_TEXT				2309
#define IMG_EDITOR_INPUT_TEXTAREA			2310
#define IMG_EDITOR_CASCADE_LIST				2311
#define IMG_EDITOR_CASCADE_LIST_ACTIVE			2312
#define IMG_EDITOR_PALETTE_BUTTON			2313
#define IMG_EDITOR_PALETTE_SCROLL_UP			2314
#define IMG_EDITOR_PALETTE_SCROLL_DOWN			2315
#define IMG_EDITOR_PALETTE_SCROLLBAR			2316
#define IMG_EDITOR_PLAYFIELD_SCROLL_UP			2317
#define IMG_EDITOR_PLAYFIELD_SCROLL_DOWN		2318
#define IMG_EDITOR_PLAYFIELD_SCROLL_LEFT		2319
#define IMG_EDITOR_PLAYFIELD_SCROLL_RIGHT		2320
#define IMG_EDITOR_PLAYFIELD_SCROLLBAR			2321
#define IMG_GFX_EDITOR_BUTTON_PREV_LEVEL		2322
#define IMG_GFX_EDITOR_BUTTON_NEXT_LEVEL		2323
#define IMG_GFX_EDITOR_BUTTON_PROPERTIES		2324
#define IMG_GFX_EDITOR_BUTTON_ELEMENT_LEFT		2325
#define IMG_GFX_EDITOR_BUTTON_ELEMENT_MIDDLE		2326
#define IMG_GFX_EDITOR_BUTTON_ELEMENT_RIGHT		2327
#define IMG_GFX_EDITOR_BUTTON_PALETTE			2328
#define IMG_EDITOR_NO_TOOLBOX_BUTTON			2329
#define IMG_GFX_EDITOR_BUTTON_DRAW_SINGLE		2330
#define IMG_GFX_EDITOR_BUTTON_DRAW_CONNECTED		2331
#define IMG_GFX_EDITOR_BUTTON_DRAW_LINE			2332
#define IMG_GFX_EDITOR_BUTTON_DRAW_ARC			2333
#define IMG_GFX_EDITOR_BUTTON_DRAW_RECTANGLE		2334
#define IMG_GFX_EDITOR_BUTTON_DRAW_FILLED_BOX		2335
#define IMG_GFX_EDITOR_BUTTON_ROTATE_UP			2336
#define IMG_GFX_EDITOR_BUTTON_DRAW_TEXT			2337
#define IMG_GFX_EDITOR_BUTTON_FLOOD_FILL		2338
#define IMG_GFX_EDITOR_BUTTON_ROTATE_LEFT		2339
#define IMG_GFX_EDITOR_BUTTON_ZOOM_LEVEL		2340
#define IMG_GFX_EDITOR_BUTTON_ROTATE_RIGHT		2341
#define IMG_GFX_EDITOR_BUTTON_DRAW_RANDOM		2342
#define IMG_GFX_EDITOR_BUTTON_GRAB_BRUSH		2343
#define IMG_GFX_EDITOR_BUTTON_ROTATE_DOWN		2344
#define IMG_GFX_EDITOR_BUTTON_PICK_ELEMENT		2345
#define IMG_GFX_EDITOR_BUTTON_CE_COPY_FROM		2346
#define IMG_GFX_EDITOR_BUTTON_CE_COPY_TO		2347
#define IMG_GFX_EDITOR_BUTTON_CE_SWAP			2348
#define IMG_GFX_EDITOR_BUTTON_CE_COPY			2349
#define IMG_GFX_EDITOR_BUTTON_CE_PASTE			2350
#define IMG_GFX_EDITOR_BUTTON_CP_COPY			2351
#define IMG_GFX_EDITOR_BUTTON_CP_PASTE			2352
#define IMG_GFX_EDITOR_BUTTON_UNDO			2353
#define IMG_GFX_EDITOR_BUTTON_CONF			2354
#define IMG_GFX_EDITOR_BUTTON_SAVE			2355
#define IMG_GFX_EDITOR_BUTTON_CLEAR			2356
#define IMG_GFX_EDITOR_BUTTON_TEST			2357
#define IMG_GFX_EDITOR_BUTTON_EXIT			2358
#define IMG_GFX_EDITOR_INPUT_LEVEL_NUMBER		2359
#define IMG_SETUP_INPUT_TEXT				2360
#define IMG_GLOBAL_BORDER				2361
#define IMG_GLOBAL_BORDER_MAIN				2362
#define IMG_GLOBAL_BORDER_SCORES			2363
#define IMG_GLOBAL_BORDER_EDITOR			2364
#define IMG_GLOBAL_BORDER_PLAYING			2365
#define IMG_GLOBAL_DOOR					2366
#define IMG_GLOBAL_BUSY_INITIAL				2367
#define IMG_GLOBAL_BUSY					2368
#define IMG_GLOBAL_BUSY_PLAYFIELD			2369
#define IMG_GLOBAL_TILE_CURSOR				2370
#define IMG_BACKGROUND					2371
#define IMG_BACKGROUND_LOADING_INITIAL			2372
#define IMG_BACKGROUND_LOADING				2373
#define IMG_BACKGROUND_TITLE_INITIAL			2374
#define IMG_BACKGROUND_TITLE				2375
#define IMG_BACKGROUND_MAIN				2376
#define IMG_BACKGROUND_NAMES				2377
#define IMG_BACKGROUND_LEVELS				2378
#define IMG_BACKGROUND_LEVELNR				2379
#define IMG_BACKGROUND_SCORES				2380
#define IMG_BACKGROUND_SCOREINFO			2381
#define IMG_BACKGROUND_EDITOR				2382
#define IMG_BACKGROUND_INFO				2383
#define IMG_BACKGROUND_INFO_ELEMENTS			2384
#define IMG_BACKGROUND_INFO_MUSIC			2385
#define IMG_BACKGROUND_INFO_CREDITS			2386
#define IMG_BACKGROUND_INFO_PROGRAM			2387
#define IMG_BACKGROUND_INFO_VERSION			2388
#define IMG_BACKGROUND_INFO_LEVELSET			2389
#define IMG_BACKGROUND_SETUP				2390
#define IMG_BACKGROUND_PLAYING				2391
#define IMG_BACKGROUND_DOOR				2392
#define IMG_BACKGROUND_TAPE				2393
#define IMG_BACKGROUND_PANEL				2394
#define IMG_BACKGROUND_PALETTE				2395
#define IMG_BACKGROUND_TOOLBOX				2396
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_1		2397
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_2		2398
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_3		2399
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_4		2400
#define IMG_BACKGROUND_TITLESCREEN_INITIAL_5		2401
#define IMG_BACKGROUND_TITLESCREEN_1			2402
#define IMG_BACKGROUND_TITLESCREEN_2			2403
#define IMG_BACKGROUND_TITLESCREEN_3			2404
#define IMG_BACKGROUND_TITLESCREEN_4			2405
#define IMG_BACKGROUND_TITLESCREEN_5			2406
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_1		2407
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_2		2408
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_3		2409
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_4		2410
#define IMG_BACKGROUND_TITLEMESSAGE_INITIAL_5		2411
#define IMG_BACKGROUND_TITLEMESSAGE_1			2412
#define IMG_BACKGROUND_TITLEMESSAGE_2			2413
#define IMG_BACKGROUND_TITLEMESSAGE_3			2414
#define IMG_BACKGROUND_TITLEMESSAGE_4			2415
#define IMG_BACKGROUND_TITLEMESSAGE_5			2416
#define IMG_BACKGROUND_ENVELOPE_1			2417
#define IMG_BACKGROUND_ENVELOPE_2			2418
#define IMG_BACKGROUND_ENVELOPE_3			2419
#define IMG_BACKGROUND_ENVELOPE_4			2420
#define IMG_BACKGROUND_REQUEST				2421
#define IMG_TITLESCREEN_INITIAL_1			2422
#define IMG_TITLESCREEN_INITIAL_2			2423
#define IMG_TITLESCREEN_INITIAL_3			2424
#define IMG_TITLESCREEN_INITIAL_4			2425
#define IMG_TITLESCREEN_INITIAL_5			2426
#define IMG_TITLESCREEN_1				2427
#define IMG_TITLESCREEN_2				2428
#define IMG_TITLESCREEN_3				2429
#define IMG_TITLESCREEN_4				2430
#define IMG_TITLESCREEN_5				2431
#define IMG_GFX_DOOR_1_PART_1				2432
#define IMG_GFX_DOOR_1_PART_2				2433
#define IMG_GFX_DOOR_1_PART_3				2434
#define IMG_GFX_DOOR_1_PART_4				2435
#define IMG_GFX_DOOR_1_PART_5				2436
#define IMG_GFX_DOOR_1_PART_6				2437
#define IMG_GFX_DOOR_1_PART_7				2438
#define IMG_GFX_DOOR_1_PART_8				2439
#define IMG_GFX_DOOR_2_PART_1				2440
#define IMG_GFX_DOOR_2_PART_2				2441
#define IMG_GFX_DOOR_2_PART_3				2442
#define IMG_GFX_DOOR_2_PART_4				2443
#define IMG_GFX_DOOR_2_PART_5				2444
#define IMG_GFX_DOOR_2_PART_6				2445
#define IMG_GFX_DOOR_2_PART_7				2446
#define IMG_GFX_DOOR_2_PART_8				2447
#define IMG_DOOR_2_TOP_BORDER_CORRECTION		2448
#define IMG_LAST_IMAGE_ENTRY_BUG			2449

#define NUM_IMAGE_FILES					2450

#endif	// CONF_GFX_H
